@@ -9,14 +9,12 @@
 import numpy as np
 
 from skbio.diversity._util import _validate_counts_vector
-from skbio.util._decorator import experimental
 
 
-@experimental(as_of="0.4.0")
-def gini_index(data, method='rectangles'):
+def gini_index(data, method="rectangles"):
     r"""Calculate the Gini index.
 
-    The Gini index is defined as
+    The Gini index is defined as:
 
     .. math::
 
@@ -43,25 +41,25 @@ def gini_index(data, method='rectangles'):
 
     Returns
     -------
-    double
+    float
         Gini index.
 
     Raises
     ------
     ValueError
-        If `method` isn't one of the supported methods for calculating the area
-        under the curve.
+        If ``method`` isn't one of the supported methods for calculating the
+        area under the curve.
 
     Notes
     -----
     The Gini index was introduced in [1]_. The formula for
-    ``method='rectangles'`` is
+    ``method='rectangles'`` is:
 
     .. math::
 
        dx\sum_{i=1}^n h_i
 
-    The formula for ``method='trapezoids'`` is
+    The formula for ``method='trapezoids'`` is:
 
     .. math::
 
@@ -74,8 +72,8 @@ def gini_index(data, method='rectangles'):
        E, Salvemini, T). Rome: Libreria Eredi Virgilio Veschi (1955).
 
     """
-    # Suppress cast to int because this method supports ints and floats.
-    data = _validate_counts_vector(data, suppress_cast=True)
+    # Suppress casting to int because this metric supports ints and floats.
+    data = _validate_counts_vector(data, cast_int=False)
     lorenz_points = _lorenz_curve(data)
     B = _lorenz_curve_integrator(lorenz_points, method)
     return max(0.0, 1 - 2 * B)
@@ -96,7 +94,7 @@ def _lorenz_curve(data):
 
 
 def _lorenz_curve_integrator(lc_pts, method):
-    """Calculates the area under a Lorenz curve.
+    """Calculate the area under a Lorenz curve.
 
     Notes
     -----
@@ -109,15 +107,17 @@ def _lorenz_curve_integrator(lc_pts, method):
     # each point differs by 1/n
     dx = 1 / x.shape[0]
 
-    if method == 'trapezoids':
+    if method == "trapezoids":
         # 0 percent of the population has zero percent of the goods
         h_0 = 0.0
         h_n = y[-1]
         # the 0th entry is at x=1/n
         sum_hs = y[:-1].sum()
         return dx * ((h_0 + h_n) / 2 + sum_hs)
-    elif method == 'rectangles':
+    elif method == "rectangles":
         return dx * y.sum()
     else:
-        raise ValueError("Method '%s' not implemented. Available methods: "
-                         "'rectangles', 'trapezoids'." % method)
+        raise ValueError(
+            "Method '%s' not implemented. Available methods: "
+            "'rectangles', 'trapezoids'." % method
+        )
