@@ -14,12 +14,13 @@ import numpy as np
 import numpy.testing as npt
 
 from skbio import DistanceMatrix, TreeNode
+from skbio.table import Table, example_table
 from skbio.util._testing import assert_series_almost_equal
 from skbio.diversity import (alpha_diversity, beta_diversity,
                              partial_beta_diversity,
                              get_alpha_diversity_metrics,
                              get_beta_diversity_metrics)
-from skbio.diversity.alpha import faith_pd, observed_otus
+from skbio.diversity.alpha import faith_pd, phydiv, sobs
 from skbio.diversity.beta import unweighted_unifrac, weighted_unifrac
 from skbio.tree import DuplicateNodeError, MissingNodeError
 from skbio.diversity._driver import (_qualitative_beta_metrics,
@@ -49,7 +50,7 @@ class AlphaDiversityTests(TestCase):
 
     def test_invalid_input(self):
         # number of ids doesn't match the number of samples
-        self.assertRaises(ValueError, alpha_diversity, 'observed_otus',
+        self.assertRaises(ValueError, alpha_diversity, 'sobs',
                           self.table1, list('ABC'))
 
         # unknown metric provided
@@ -57,30 +58,33 @@ class AlphaDiversityTests(TestCase):
                           self.table1)
 
         # 3-D list provided as input
-        self.assertRaises(ValueError, alpha_diversity, 'observed_otus',
+        self.assertRaises(ValueError, alpha_diversity, 'sobs',
                           [[[43]]])
 
         # negative counts
-        self.assertRaises(ValueError, alpha_diversity, 'observed_otus',
+        self.assertRaises(ValueError, alpha_diversity, 'sobs',
                           [0, 3, -12, 42])
 
         # additional kwargs
-        self.assertRaises(TypeError, alpha_diversity, 'observed_otus',
+        self.assertRaises(TypeError, alpha_diversity, 'sobs',
                           [0, 1], not_a_real_kwarg=42.0)
         self.assertRaises(TypeError, alpha_diversity, 'faith_pd',
-                          [0, 1], tree=self.tree1, otu_ids=['OTU1', 'OTU2'],
+                          [0, 1], tree=self.tree1, taxa=['OTU1', 'OTU2'],
                           not_a_real_kwarg=42.0)
         self.assertRaises(TypeError, alpha_diversity, faith_pd,
-                          [0, 1], tree=self.tree1, otu_ids=['OTU1', 'OTU2'],
+                          [0, 1], tree=self.tree1, taxa=['OTU1', 'OTU2'],
                           not_a_real_kwarg=42.0)
 
+        self.assertRaises(ValueError, alpha_diversity, 'sobs',
+                          example_table, ids=['A', 'B', 'C'])
+
     def test_invalid_input_phylogenetic(self):
-        # otu_ids not provided
+        # taxa not provided
         self.assertRaises(ValueError, alpha_diversity, 'faith_pd', self.table1,
                           list('ABC'), tree=self.tree1)
         # tree not provided
         self.assertRaises(ValueError, alpha_diversity, 'faith_pd', self.table1,
-                          list('ABC'), otu_ids=self.oids1)
+                          list('ABC'), taxa=self.oids1)
 
         # tree has duplicated tip ids
         t = TreeNode.read(
@@ -88,27 +92,27 @@ class AlphaDiversityTests(TestCase):
                 '(((((OTU2:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU5:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(DuplicateNodeError, alpha_diversity, 'faith_pd',
-                          counts, otu_ids=otu_ids, tree=t)
+                          counts, taxa=taxa, tree=t)
 
         # unrooted tree as input
         t = TreeNode.read(io.StringIO(
             '((OTU1:0.1, OTU2:0.2):0.3, OTU3:0.5,OTU4:0.7);'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(ValueError, alpha_diversity, 'faith_pd',
-                          counts, otu_ids=otu_ids, tree=t)
+                          counts, taxa=taxa, tree=t)
 
-        # otu_ids has duplicated ids
+        # taxa has duplicated ids
         t = TreeNode.read(
             io.StringIO(
                 '(((((OTU1:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU2:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU2']
+        taxa = ['OTU1', 'OTU2', 'OTU2']
         self.assertRaises(ValueError, alpha_diversity, 'faith_pd',
-                          counts, otu_ids=otu_ids, tree=t)
+                          counts, taxa=taxa, tree=t)
 
         # count and OTU vectors are not equal length
         t = TreeNode.read(
@@ -116,117 +120,147 @@ class AlphaDiversityTests(TestCase):
                 '(((((OTU1:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU2:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2']
+        taxa = ['OTU1', 'OTU2']
         self.assertRaises(ValueError, alpha_diversity, 'faith_pd',
-                          counts, otu_ids=otu_ids, tree=t)
+                          counts, taxa=taxa, tree=t)
         t = TreeNode.read(
             io.StringIO(
                 '(((((OTU1:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU2:0.75):1.25):0.0)root;'))
         counts = [1, 2]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(ValueError, alpha_diversity, 'faith_pd',
-                          counts, otu_ids=otu_ids, tree=t)
+                          counts, taxa=taxa, tree=t)
 
         # tree with no branch lengths
         t = TreeNode.read(
             io.StringIO('((((OTU1,OTU2),OTU3)),(OTU4,OTU5));'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(ValueError, alpha_diversity, 'faith_pd',
-                          counts, otu_ids=otu_ids, tree=t)
+                          counts, taxa=taxa, tree=t)
 
         # tree missing some branch lengths
         t = TreeNode.read(
             io.StringIO('(((((OTU1,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                         '0.75,OTU5:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(ValueError, alpha_diversity, 'faith_pd',
-                          counts, otu_ids=otu_ids, tree=t)
+                          counts, taxa=taxa, tree=t)
 
-        # some otu_ids not present in tree
+        # some taxa not present in tree
         t = TreeNode.read(
             io.StringIO(
                 '(((((OTU1:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU5:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU42']
+        taxa = ['OTU1', 'OTU2', 'OTU42']
         self.assertRaises(MissingNodeError, alpha_diversity, 'faith_pd',
-                          counts, otu_ids=otu_ids, tree=t)
+                          counts, taxa=taxa, tree=t)
+
+        # table and taxa are provided
+        test_table = Table(np.array([[1, 2, 3], [4, 5, 6], [7, 8, 9]]),
+                           ['O1', 'O2', 'O3'],
+                           ['S1', 'S2', 'S3'])
+        self.assertRaises(ValueError, alpha_diversity, 'faith_pd',
+                          test_table, taxa=taxa, tree=t)
 
     def test_empty(self):
         # empty vector
-        actual = alpha_diversity('observed_otus', np.array([], dtype=np.int64))
-        expected = pd.Series([0])
+        actual = alpha_diversity('sobs', np.array([], dtype=np.int64))
+        expected = pd.Series([0], dtype=np.int64)
         assert_series_almost_equal(actual, expected)
 
         # array of empty vector
-        actual = alpha_diversity('observed_otus',
-                                 np.array([[]], dtype=np.int64))
-        expected = pd.Series([0])
+        actual = alpha_diversity('sobs', np.array([[]], dtype=np.int64))
+        expected = pd.Series([0], dtype=np.int64)
         assert_series_almost_equal(actual, expected)
 
         # array of empty vectors
-        actual = alpha_diversity('observed_otus',
-                                 np.array([[], []], dtype=np.int64))
-        expected = pd.Series([0, 0])
+        actual = alpha_diversity('sobs', np.array([[], []], dtype=np.int64))
+        expected = pd.Series([0, 0], dtype=np.int64)
         assert_series_almost_equal(actual, expected)
 
         # empty vector
         actual = alpha_diversity('faith_pd', np.array([], dtype=np.int64),
-                                 tree=self.tree1, otu_ids=[])
+                                 tree=self.tree1, taxa=[])
         expected = pd.Series([0.])
         assert_series_almost_equal(actual, expected)
 
         # array of empty vector
         actual = alpha_diversity('faith_pd',
                                  np.array([[]], dtype=np.int64),
-                                 tree=self.tree1, otu_ids=[])
+                                 tree=self.tree1, taxa=[])
         expected = pd.Series([0.])
         assert_series_almost_equal(actual, expected)
 
         # array of empty vectors
         actual = alpha_diversity('faith_pd',
                                  np.array([[], []], dtype=np.int64),
-                                 tree=self.tree1, otu_ids=[])
+                                 tree=self.tree1, taxa=[])
         expected = pd.Series([0., 0.])
         assert_series_almost_equal(actual, expected)
 
+        # empty Table
+        actual = alpha_diversity('sobs', Table(np.array([[]]), [], ['S1', ]))
+        actual.index = pd.RangeIndex(len(actual))
+        expected = pd.Series([0], dtype=np.int64)
+        assert_series_almost_equal(actual, expected)
+
     def test_single_count_vector(self):
-        actual = alpha_diversity('observed_otus', np.array([1, 0, 2]))
-        expected = pd.Series([2])
+        actual = alpha_diversity('sobs', np.array([1, 0, 2]))
+        expected = pd.Series([2], dtype=np.int64)
         assert_series_almost_equal(actual, expected)
 
         actual = alpha_diversity('faith_pd', np.array([1, 3, 0, 1, 0]),
-                                 tree=self.tree1, otu_ids=self.oids1)
+                                 tree=self.tree1, taxa=self.oids1)
         self.assertAlmostEqual(actual[0], 4.5)
 
     def test_input_types(self):
-        list_result = alpha_diversity('observed_otus', [1, 3, 0, 1, 0])
-        array_result = alpha_diversity('observed_otus',
+        list_result = alpha_diversity('sobs', [1, 3, 0, 1, 0])
+        array_result = alpha_diversity('sobs',
                                        np.array([1, 3, 0, 1, 0]))
+        table_result = alpha_diversity('sobs',
+                                       Table(np.array([[1, 3, 0, 1, 0], ]).T,
+                                             list('ABCDE'),
+                                             ['S1', ]))
+
+        # using a table we get sample IDs for free, drop them for the test
+        table_result.index = pd.RangeIndex(len(table_result))
+
         self.assertAlmostEqual(list_result[0], 3)
         assert_series_almost_equal(list_result, array_result)
+        assert_series_almost_equal(table_result, array_result)
 
         list_result = alpha_diversity('faith_pd', [1, 3, 0, 1, 0],
-                                      tree=self.tree1, otu_ids=self.oids1)
+                                      tree=self.tree1, taxa=self.oids1)
         array_result = alpha_diversity('faith_pd', np.array([1, 3, 0, 1, 0]),
-                                       tree=self.tree1, otu_ids=self.oids1)
+                                       tree=self.tree1, taxa=self.oids1)
+        table_result = alpha_diversity('faith_pd',
+                                       Table(np.array([[1, 3, 0, 1, 0], ]).T,
+                                             self.oids1,
+                                             ['S1', ]),
+                                       tree=self.tree1)
+
+        # using a table we get sample IDs for free, drop them for the test
+        table_result.index = pd.RangeIndex(len(table_result))
+
         self.assertAlmostEqual(list_result[0], 4.5)
         assert_series_almost_equal(list_result, array_result)
+        assert_series_almost_equal(table_result, array_result)
 
-    def test_observed_otus(self):
+    def test_sobs(self):
         # expected values hand-calculated
-        expected = pd.Series([3, 3, 3, 3], index=self.sids1)
-        actual = alpha_diversity('observed_otus', self.table1, self.sids1)
+        expected = pd.Series([3, 3, 3, 3], index=self.sids1, dtype=np.int64)
+        actual = alpha_diversity('sobs', self.table1, self.sids1)
         assert_series_almost_equal(actual, expected)
         # function passed instead of string
-        actual = alpha_diversity(observed_otus, self.table1, self.sids1)
+        actual = alpha_diversity(sobs, self.table1, self.sids1)
         assert_series_almost_equal(actual, expected)
         # alt input table
-        expected = pd.Series([2, 1, 0], index=self.sids2)
-        actual = alpha_diversity('observed_otus', self.table2, self.sids2)
+        expected = pd.Series([2, 1, 0], index=self.sids2, dtype=np.int64)
+        actual = alpha_diversity('sobs', self.table2, self.sids2)
         assert_series_almost_equal(actual, expected)
 
     def test_faith_pd(self):
@@ -234,34 +268,61 @@ class AlphaDiversityTests(TestCase):
         # calling it directly
         expected = []
         for e in self.table1:
-            expected.append(faith_pd(e, tree=self.tree1, otu_ids=self.oids1))
+            expected.append(faith_pd(e, tree=self.tree1, taxa=self.oids1))
         expected = pd.Series(expected)
         actual = alpha_diversity('faith_pd', self.table1, tree=self.tree1,
-                                 otu_ids=self.oids1)
+                                 taxa=self.oids1)
         assert_series_almost_equal(actual, expected)
 
         # alt input table and tree
         expected = []
         for e in self.table2:
-            expected.append(faith_pd(e, tree=self.tree2, otu_ids=self.oids2))
+            expected.append(faith_pd(e, tree=self.tree2, taxa=self.oids2))
         expected = pd.Series(expected)
         actual = alpha_diversity('faith_pd', self.table2, tree=self.tree2,
-                                 otu_ids=self.oids2)
+                                 taxa=self.oids2)
+        assert_series_almost_equal(actual, expected)
+
+    def test_phydiv(self):
+        expected = []
+        for e in self.table1:
+            expected.append(phydiv(e, tree=self.tree1, taxa=self.oids1))
+        expected = pd.Series(expected)
+        actual = alpha_diversity('phydiv', self.table1, tree=self.tree1,
+                                 taxa=self.oids1)
+        assert_series_almost_equal(actual, expected)
+
+        expected = []
+        for e in self.table1:
+            expected.append(phydiv(e, tree=self.tree1, taxa=self.oids1,
+                                   rooted=False))
+        expected = pd.Series(expected)
+        actual = alpha_diversity('phydiv', self.table1, tree=self.tree1,
+                                 taxa=self.oids1, rooted=False)
+        assert_series_almost_equal(actual, expected)
+
+        expected = []
+        for e in self.table1:
+            expected.append(phydiv(e, tree=self.tree1, taxa=self.oids1,
+                                   weight=True))
+        expected = pd.Series(expected)
+        actual = alpha_diversity('phydiv', self.table1, tree=self.tree1,
+                                 taxa=self.oids1, weight=True)
         assert_series_almost_equal(actual, expected)
 
     def test_no_ids(self):
         # expected values hand-calculated
-        expected = pd.Series([3, 3, 3, 3])
-        actual = alpha_diversity('observed_otus', self.table1)
+        expected = pd.Series([3, 3, 3, 3], dtype=np.int64)
+        actual = alpha_diversity('sobs', self.table1)
         assert_series_almost_equal(actual, expected)
 
     def test_optimized(self):
         # calling optimized faith_pd gives same results as calling unoptimized
         # version
         optimized = alpha_diversity('faith_pd', self.table1, tree=self.tree1,
-                                    otu_ids=self.oids1)
+                                    taxa=self.oids1)
         unoptimized = alpha_diversity(faith_pd, self.table1, tree=self.tree1,
-                                      otu_ids=self.oids1)
+                                      taxa=self.oids1)
         assert_series_almost_equal(optimized, unoptimized)
 
 
@@ -301,6 +362,18 @@ class BetaDiversityTests(TestCase):
                 raise ValueError(
                     f'Metric {metric} failed with exception:\n {exc}')
 
+    def test_use_of_dataframe_index(self):
+        '''reference to issue 1808'''
+
+        df1 = pd.DataFrame(self.table1, index=self.sids1)
+        df2 = pd.DataFrame(self.table2, index=self.sids2)
+
+        matrix1 = beta_diversity('jaccard', df1)
+        matrix2 = beta_diversity('jaccard', df2)
+
+        self.assertEqual(self.sids1, list(matrix1.to_data_frame().index))
+        self.assertEqual(self.sids2, list(matrix2.to_data_frame().index))
+
     def test_qualitative_bug_issue_1549(self):
         as_presence_absence = np.asarray(self.table3) > 0
 
@@ -343,27 +416,36 @@ class BetaDiversityTests(TestCase):
         with self.assertRaisesRegex(TypeError, error_msg):
             beta_diversity('unweighted_unifrac', [[0, 1, 3], [0, 3, 12]],
                            not_a_real_kwarg=42.0, tree=self.tree1,
-                           otu_ids=['O1', 'O2', 'O3'])
+                           taxa=['O1', 'O2', 'O3'])
         with self.assertRaisesRegex(TypeError, error_msg):
             beta_diversity('weighted_unifrac', [[0, 1, 3], [0, 3, 12]],
                            not_a_real_kwarg=42.0, tree=self.tree1,
-                           otu_ids=['O1', 'O2', 'O3'])
+                           taxa=['O1', 'O2', 'O3'])
         with self.assertRaisesRegex(TypeError, error_msg):
             beta_diversity(weighted_unifrac, [[0, 1, 3], [0, 3, 12]],
                            not_a_real_kwarg=42.0, tree=self.tree1,
-                           otu_ids=['O1', 'O2', 'O3'])
+                           taxa=['O1', 'O2', 'O3'])
+
+        error_msg = r"`counts` and `ids`"
+        with self.assertRaisesRegex(ValueError, error_msg):
+            beta_diversity('euclidean', example_table, ids=['foo', 'bar'])
+
+        error_msg = r"`counts` and `taxa`"
+        with self.assertRaisesRegex(ValueError, error_msg):
+            beta_diversity(weighted_unifrac, example_table, taxa=['foo', 'bar'],
+                           tree=self.tree1)
 
     def test_invalid_input_phylogenetic(self):
-        # otu_ids not provided
+        # taxa not provided
         self.assertRaises(ValueError, beta_diversity, 'weighted_unifrac',
                           self.table1, list('ABC'), tree=self.tree1)
         self.assertRaises(ValueError, beta_diversity, 'unweighted_unifrac',
                           self.table1, list('ABC'), tree=self.tree1)
         # tree not provided
         self.assertRaises(ValueError, beta_diversity, 'weighted_unifrac',
-                          self.table1, list('ABC'), otu_ids=self.oids1)
+                          self.table1, list('ABC'), taxa=self.oids1)
         self.assertRaises(ValueError, beta_diversity, 'unweighted_unifrac',
-                          self.table1, list('ABC'), otu_ids=self.oids1)
+                          self.table1, list('ABC'), taxa=self.oids1)
 
         # tree has duplicated tip ids
         t = TreeNode.read(
@@ -371,35 +453,35 @@ class BetaDiversityTests(TestCase):
                 '(((((OTU2:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU5:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(DuplicateNodeError, beta_diversity,
-                          'weighted_unifrac', counts, otu_ids=otu_ids, tree=t)
+                          'weighted_unifrac', counts, taxa=taxa, tree=t)
         self.assertRaises(DuplicateNodeError, beta_diversity,
-                          'unweighted_unifrac', counts, otu_ids=otu_ids,
+                          'unweighted_unifrac', counts, taxa=taxa,
                           tree=t)
 
         # unrooted tree as input
         t = TreeNode.read(io.StringIO('((OTU1:0.1, OTU2:0.2):0.3, OTU3:0.5,'
                                       'OTU4:0.7);'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(ValueError, beta_diversity,
-                          'weighted_unifrac', counts, otu_ids=otu_ids, tree=t)
+                          'weighted_unifrac', counts, taxa=taxa, tree=t)
         self.assertRaises(ValueError, beta_diversity,
-                          'unweighted_unifrac', counts, otu_ids=otu_ids,
+                          'unweighted_unifrac', counts, taxa=taxa,
                           tree=t)
 
-        # otu_ids has duplicated ids
+        # taxa has duplicated ids
         t = TreeNode.read(
             io.StringIO(
                 '(((((OTU1:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU2:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU2']
+        taxa = ['OTU1', 'OTU2', 'OTU2']
         self.assertRaises(ValueError, beta_diversity,
-                          'weighted_unifrac', counts, otu_ids=otu_ids, tree=t)
+                          'weighted_unifrac', counts, taxa=taxa, tree=t)
         self.assertRaises(ValueError, beta_diversity,
-                          'unweighted_unifrac', counts, otu_ids=otu_ids,
+                          'unweighted_unifrac', counts, taxa=taxa,
                           tree=t)
 
         # count and OTU vectors are not equal length
@@ -408,33 +490,33 @@ class BetaDiversityTests(TestCase):
                 '(((((OTU1:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU2:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2']
+        taxa = ['OTU1', 'OTU2']
         self.assertRaises(ValueError, beta_diversity,
-                          'weighted_unifrac', counts, otu_ids=otu_ids, tree=t)
+                          'weighted_unifrac', counts, taxa=taxa, tree=t)
         self.assertRaises(ValueError, beta_diversity,
-                          'unweighted_unifrac', counts, otu_ids=otu_ids,
+                          'unweighted_unifrac', counts, taxa=taxa,
                           tree=t)
         t = TreeNode.read(
             io.StringIO(
                 '(((((OTU1:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU2:0.75):1.25):0.0)root;'))
         counts = [1, 2]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(ValueError, beta_diversity,
-                          'weighted_unifrac', counts, otu_ids=otu_ids, tree=t)
+                          'weighted_unifrac', counts, taxa=taxa, tree=t)
         self.assertRaises(ValueError, beta_diversity,
-                          'unweighted_unifrac', counts, otu_ids=otu_ids,
+                          'unweighted_unifrac', counts, taxa=taxa,
                           tree=t)
 
         # tree with no branch lengths
         t = TreeNode.read(
             io.StringIO('((((OTU1,OTU2),OTU3)),(OTU4,OTU5));'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(ValueError, beta_diversity,
-                          'weighted_unifrac', counts, otu_ids=otu_ids, tree=t)
+                          'weighted_unifrac', counts, taxa=taxa, tree=t)
         self.assertRaises(ValueError, beta_diversity,
-                          'unweighted_unifrac', counts, otu_ids=otu_ids,
+                          'unweighted_unifrac', counts, taxa=taxa,
                           tree=t)
 
         # tree missing some branch lengths
@@ -442,24 +524,24 @@ class BetaDiversityTests(TestCase):
             io.StringIO('(((((OTU1,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                         '0.75,OTU5:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU3']
+        taxa = ['OTU1', 'OTU2', 'OTU3']
         self.assertRaises(ValueError, beta_diversity,
-                          'weighted_unifrac', counts, otu_ids=otu_ids, tree=t)
+                          'weighted_unifrac', counts, taxa=taxa, tree=t)
         self.assertRaises(ValueError, beta_diversity,
-                          'unweighted_unifrac', counts, otu_ids=otu_ids,
+                          'unweighted_unifrac', counts, taxa=taxa,
                           tree=t)
 
-        # some otu_ids not present in tree
+        # some taxa not present in tree
         t = TreeNode.read(
             io.StringIO(
                 '(((((OTU1:0.5,OTU2:0.5):0.5,OTU3:1.0):1.0):0.0,(OTU4:'
                 '0.75,OTU5:0.75):1.25):0.0)root;'))
         counts = [1, 2, 3]
-        otu_ids = ['OTU1', 'OTU2', 'OTU42']
+        taxa = ['OTU1', 'OTU2', 'OTU42']
         self.assertRaises(MissingNodeError, beta_diversity,
-                          'weighted_unifrac', counts, otu_ids=otu_ids, tree=t)
+                          'weighted_unifrac', counts, taxa=taxa, tree=t)
         self.assertRaises(MissingNodeError, beta_diversity,
-                          'unweighted_unifrac', counts, otu_ids=otu_ids,
+                          'unweighted_unifrac', counts, taxa=taxa,
                           tree=t)
 
     def test_empty(self):
@@ -472,7 +554,13 @@ class BetaDiversityTests(TestCase):
 
         actual = beta_diversity('unweighted_unifrac',
                                 np.array([[], []], dtype=np.int64),
-                                ids=['a', 'b'], tree=self.tree1, otu_ids=[])
+                                ids=['a', 'b'], tree=self.tree1, taxa=[])
+        expected_dm = DistanceMatrix([[0.0, 0.0], [0.0, 0.0]], ['a', 'b'])
+        self.assertEqual(actual, expected_dm)
+
+        actual = beta_diversity('unweighted_unifrac',
+                                Table(np.array([[], []]).T, [], ['a', 'b']),
+                                tree=self.tree1)
         expected_dm = DistanceMatrix([[0.0, 0.0], [0.0, 0.0]], ['a', 'b'])
         self.assertEqual(actual, expected_dm)
 
@@ -482,7 +570,12 @@ class BetaDiversityTests(TestCase):
                                       ids=['a', 'b'])
         actual_list = beta_diversity('euclidean',
                                      [[1, 5], [2, 3]], ids=['a', 'b'])
+        actual_table = beta_diversity('euclidean',
+                                      Table(np.array([[1, 5], [2, 3]]).T,
+                                            ['O1', 'O2'],
+                                            ['a', 'b']))
         self.assertEqual(actual_array, actual_list)
+        self.assertEqual(actual_array, actual_table)
 
     def test_euclidean(self):
         # TODO: update npt.assert_almost_equal calls to use DistanceMatrix
@@ -547,9 +640,9 @@ class BetaDiversityTests(TestCase):
         # near-equality testing when that support is available
         # expected values calculated by hand
         dm1 = beta_diversity('unweighted_unifrac', self.table1, self.sids1,
-                             otu_ids=self.oids1, tree=self.tree1)
+                             taxa=self.oids1, tree=self.tree1)
         dm2 = beta_diversity(unweighted_unifrac, self.table1, self.sids1,
-                             otu_ids=self.oids1, tree=self.tree1)
+                             taxa=self.oids1, tree=self.tree1)
         self.assertEqual(dm1.shape, (3, 3))
         self.assertEqual(dm1, dm2)
         expected_data = [[0.0, 0.0, 0.25],
@@ -566,9 +659,9 @@ class BetaDiversityTests(TestCase):
         # near-equality testing when that support is available
         # expected values calculated by hand
         dm1 = beta_diversity('weighted_unifrac', self.table1, self.sids1,
-                             otu_ids=self.oids1, tree=self.tree1)
+                             taxa=self.oids1, tree=self.tree1)
         dm2 = beta_diversity(weighted_unifrac, self.table1, self.sids1,
-                             otu_ids=self.oids1, tree=self.tree1)
+                             taxa=self.oids1, tree=self.tree1)
         self.assertEqual(dm1.shape, (3, 3))
         self.assertEqual(dm1, dm2)
         expected_data = [
@@ -586,10 +679,10 @@ class BetaDiversityTests(TestCase):
         # near-equality testing when that support is available
         # expected values calculated by hand
         dm1 = beta_diversity('weighted_unifrac', self.table1, self.sids1,
-                             otu_ids=self.oids1, tree=self.tree1,
+                             taxa=self.oids1, tree=self.tree1,
                              normalized=True)
         dm2 = beta_diversity(weighted_unifrac, self.table1, self.sids1,
-                             otu_ids=self.oids1, tree=self.tree1,
+                             taxa=self.oids1, tree=self.tree1,
                              normalized=True)
         self.assertEqual(dm1.shape, (3, 3))
         self.assertEqual(dm1, dm2)
@@ -620,19 +713,19 @@ class BetaDiversityTests(TestCase):
         def not_a_real_pdist(counts, metric):
             return [[0.0, 42.0], [42.0, 0.0]]
         dm1 = beta_diversity('unweighted_unifrac', self.table1,
-                             otu_ids=self.oids1, tree=self.tree1,
+                             taxa=self.oids1, tree=self.tree1,
                              pairwise_func=not_a_real_pdist)
         expected = DistanceMatrix([[0.0, 42.0], [42.0, 0.0]])
         self.assertEqual(dm1, expected)
 
         dm1 = beta_diversity('weighted_unifrac', self.table1,
-                             otu_ids=self.oids1, tree=self.tree1,
+                             taxa=self.oids1, tree=self.tree1,
                              pairwise_func=not_a_real_pdist)
         expected = DistanceMatrix([[0.0, 42.0], [42.0, 0.0]])
         self.assertEqual(dm1, expected)
 
         dm1 = beta_diversity(unweighted_unifrac, self.table1,
-                             otu_ids=self.oids1, tree=self.tree1,
+                             taxa=self.oids1, tree=self.tree1,
                              pairwise_func=not_a_real_pdist)
         expected = DistanceMatrix([[0.0, 42.0], [42.0, 0.0]])
         self.assertEqual(dm1, expected)
@@ -689,7 +782,7 @@ class TestPartialBetaDiversity(TestCase):
     def test_id_pairs_as_iterable(self):
         id_pairs = iter([('B', 'C'), ])
         dm = partial_beta_diversity('unweighted_unifrac', self.table1,
-                                    self.sids1, otu_ids=self.oids1,
+                                    self.sids1, taxa=self.oids1,
                                     tree=self.tree1, id_pairs=id_pairs)
         self.assertEqual(dm.shape, (3, 3))
         expected_data = [[0.0, 0.0, 0.0],
@@ -708,7 +801,7 @@ class TestPartialBetaDiversity(TestCase):
         # near-equality testing when that support is available
         # expected values calculated by hand
         dm = partial_beta_diversity('unweighted_unifrac', self.table1,
-                                    self.sids1, otu_ids=self.oids1,
+                                    self.sids1, taxa=self.oids1,
                                     tree=self.tree1, id_pairs=[('B', 'C'), ])
         self.assertEqual(dm.shape, (3, 3))
         expected_data = [[0.0, 0.0, 0.0],
@@ -725,12 +818,12 @@ class TestPartialBetaDiversity(TestCase):
         # near-equality testing when that support is available
         # expected values calculated by hand
         dm1 = partial_beta_diversity('weighted_unifrac', self.table1,
-                                     self.sids1, otu_ids=self.oids1,
+                                     self.sids1, taxa=self.oids1,
                                      tree=self.tree1, id_pairs=[('A', 'B'),
                                                                 ('A', 'C'),
                                                                 ('B', 'C')])
         dm2 = beta_diversity('weighted_unifrac', self.table1, self.sids1,
-                             otu_ids=self.oids1, tree=self.tree1)
+                             taxa=self.oids1, tree=self.tree1)
 
         self.assertEqual(dm1.shape, (3, 3))
         self.assertEqual(dm1, dm2)
