@@ -15,8 +15,11 @@ import itertools
 import requests
 
 from skbio.io import IOSourceError
-from ._fileobject import (IterableStringWriterIO, IterableStringReaderIO,
-                          WrappedBufferedRandom)
+from ._fileobject import (
+    IterableStringWriterIO,
+    IterableStringReaderIO,
+    WrappedBufferedRandom,
+)
 
 
 # NamedTemporaryFile isn't an actual file class, it is a function which
@@ -36,20 +39,17 @@ def get_io_sources():
         BufferedIOSource,
         TextIOSource,
         WrappedTemporaryFileSource,
-        IterableSource
+        IterableSource,
     )
 
 
 def _compressors():
-    return (
-        GzipCompressor,
-        BZ2Compressor
-    )
+    return (GzipCompressor, BZ2Compressor)
 
 
 def get_compression_handler(name):
     compressors = {c.name: c for c in _compressors()}
-    compressors['auto'] = AutoCompressor
+    compressors["auto"] = AutoCompressor
     return compressors.get(name, False)
 
 
@@ -75,7 +75,7 @@ class IOSource:
 
 class Compressor(IOSource):
     streamable = True
-    name = ''
+    name = ""
 
     def can_write(self):
         return True
@@ -89,17 +89,17 @@ class FilePathSource(IOSource):
         return self.can_read()
 
     def get_reader(self):
-        return io.open(self.file, mode='rb')
+        return io.open(self.file, mode="rb")
 
     def get_writer(self):
-        return io.open(self.file, mode='wb')
+        return io.open(self.file, mode="wb")
 
 
 class HTTPSource(IOSource):
     def can_read(self):
-        return (
-            isinstance(self.file, str) and
-            requests.compat.urlparse(self.file).scheme in {'http', 'https'})
+        return isinstance(self.file, str) and requests.compat.urlparse(
+            self.file
+        ).scheme in {"http", "https"}
 
     def get_reader(self):
         req = requests.get(self.file)
@@ -166,12 +166,10 @@ class WrappedTemporaryFileSource(IOSource):
     closeable = False
 
     def can_read(self):
-        return (isinstance(self.file, _WrappedTemporaryFile) and
-                self.file.readable())
+        return isinstance(self.file, _WrappedTemporaryFile) and self.file.readable()
 
     def can_write(self):
-        return (isinstance(self.file, _WrappedTemporaryFile) and
-                self.file.writable())
+        return isinstance(self.file, _WrappedTemporaryFile) and self.file.writable()
 
     def get_reader(self):
         # _TemporaryFileWrapper has a file attribute which is an actual fileobj
@@ -183,7 +181,7 @@ class WrappedTemporaryFileSource(IOSource):
 
 class IterableSource(IOSource):
     def can_read(self):
-        if hasattr(self.file, '__iter__'):
+        if hasattr(self.file, "__iter__"):
             iterator = iter(self.file)
             head = next(iterator, None)
             if head is None:
@@ -195,55 +193,56 @@ class IterableSource(IOSource):
             else:
                 # We may have mangled a generator at this point, so just abort
                 raise IOSourceError(
-                    "Could not open source: %r (mode: %r)" %
-                    (self.file, self.options['mode']))
+                    "Could not open source: %r (mode: %r)"
+                    % (self.file, self.options["mode"])
+                )
         return False
 
     def can_write(self):
-        return hasattr(self.file, 'append') and hasattr(self.file, '__iter__')
+        return hasattr(self.file, "append") and hasattr(self.file, "__iter__")
 
     def get_reader(self):
-        return IterableStringReaderIO(self.repaired,
-                                      newline=self.options['newline'])
+        return IterableStringReaderIO(self.repaired, newline=self.options["newline"])
 
     def get_writer(self):
-        return IterableStringWriterIO(self.file,
-                                      newline=self.options['newline'])
+        return IterableStringWriterIO(self.file, newline=self.options["newline"])
 
 
 class GzipCompressor(Compressor):
-    name = 'gzip'
+    name = "gzip"
     streamable = True
 
     def can_read(self):
-        return self.file.peek(2)[:2] == b'\x1f\x8b'
+        return self.file.peek(2)[:2] == b"\x1f\x8b"
 
     def get_reader(self):
         return gzip.GzipFile(fileobj=self.file)
 
     def get_writer(self):
-        return gzip.GzipFile(fileobj=self.file, mode='wb',
-                             compresslevel=self.options['compresslevel'])
+        return gzip.GzipFile(
+            fileobj=self.file, mode="wb", compresslevel=self.options["compresslevel"]
+        )
 
 
 class BZ2Compressor(Compressor):
-    name = 'bz2'
+    name = "bz2"
     streamable = False
 
     def can_read(self):
-        return self.file.peek(3)[:3] == b'BZh'
+        return self.file.peek(3)[:3] == b"BZh"
 
     def get_reader(self):
-        return bz2.BZ2File(self.file, mode='rb')
+        return bz2.BZ2File(self.file, mode="rb")
 
     def get_writer(self):
-        return bz2.BZ2File(self.file, mode='wb',
-                           compresslevel=self.options['compresslevel'])
+        return bz2.BZ2File(
+            self.file, mode="wb", compresslevel=self.options["compresslevel"]
+        )
 
 
 class AutoCompressor(Compressor):
     streamable = True  # We can' write so it doesn't matter
-    name = 'auto'
+    name = "auto"
 
     def get_reader(self):
         for compression_handler in _compressors():
