@@ -6,14 +6,14 @@
 # The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
+from warnings import warn
 from abc import ABCMeta, abstractproperty
 from itertools import product
 import re
 
 import numpy as np
 
-from skbio.util._decorator import (classproperty, overrides, stable,
-                                   deprecated, experimental)
+from skbio.util._decorator import classproperty, overrides
 from skbio.util._misc import MiniRegistry
 from ._sequence import Sequence
 
@@ -22,14 +22,10 @@ class GrammaredSequenceMeta(ABCMeta, type):
     def __new__(mcs, name, bases, dct):
         cls = super(GrammaredSequenceMeta, mcs).__new__(mcs, name, bases, dct)
 
-        concrete_gap_chars = \
-            type(cls.gap_chars) is not abstractproperty
-        concrete_degenerate_map = \
-            type(cls.degenerate_map) is not abstractproperty
-        concrete_definite_chars = \
-            type(cls.definite_chars) is not abstractproperty
-        concrete_default_gap_char = \
-            type(cls.default_gap_char) is not abstractproperty
+        concrete_gap_chars = type(cls.gap_chars) is not abstractproperty
+        concrete_degenerate_map = type(cls.degenerate_map) is not abstractproperty
+        concrete_definite_chars = type(cls.definite_chars) is not abstractproperty
+        concrete_default_gap_char = type(cls.default_gap_char) is not abstractproperty
         # degenerate_chars is not abstract but it depends on degenerate_map
         # which is abstract.
         concrete_degenerate_chars = concrete_degenerate_map
@@ -39,19 +35,23 @@ class GrammaredSequenceMeta(ABCMeta, type):
         # TODO: Rather than hard-coding a list of attributes to check, we can
         # probably check all the attributes on the class and make sure none of
         # them are abstract.
-        if (concrete_gap_chars and concrete_degenerate_map and
-                concrete_definite_chars and concrete_default_gap_char and
-                concrete_degenerate_chars):
-
+        if (
+            concrete_gap_chars
+            and concrete_degenerate_map
+            and concrete_definite_chars
+            and concrete_default_gap_char
+            and concrete_degenerate_chars
+        ):
             if cls.default_gap_char not in cls.gap_chars:
                 raise TypeError(
-                    "default_gap_char must be in gap_chars for class %s" %
-                    name)
+                    "default_gap_char must be in gap_chars for class %s" % name
+                )
 
             if len(cls.gap_chars & cls.degenerate_chars) > 0:
                 raise TypeError(
                     "gap_chars and degenerate_chars must not share any "
-                    "characters for class %s" % name)
+                    "characters for class %s" % name
+                )
 
             for key in cls.degenerate_map.keys():
                 for definite_char in cls.degenerate_map[key]:
@@ -59,40 +59,24 @@ class GrammaredSequenceMeta(ABCMeta, type):
                         raise TypeError(
                             "degenerate_map must expand only to "
                             "characters included in definite_chars "
-                            "for class %s" % name)
+                            "for class %s" % name
+                        )
 
             if len(cls.degenerate_chars & cls.definite_chars) > 0:
                 raise TypeError(
                     "degenerate_chars and definite_chars must not "
-                    "share any characters for class %s" % name)
+                    "share any characters for class %s" % name
+                )
 
             if len(cls.gap_chars & cls.definite_chars) > 0:
                 raise TypeError(
                     "gap_chars and definite_chars must not share any "
-                    "characters for class %s" % name)
+                    "characters for class %s" % name
+                )
 
         return cls
 
 
-# Adapted from http://stackoverflow.com/a/16056691/943814
-# Note that inheriting from GrammaredSequenceMeta, rather than something
-# more general, is intentional. Multiple inheritance with metaclasses can be
-# tricky and is not handled automatically in Python. Since this class needs to
-# inherit both from ABCMeta and GrammaredSequenceMeta, the only way we could
-# find to make this work was to have GrammaredSequenceMeta inherit from ABCMeta
-# and then inherit from GrammaredSequenceMeta here.
-class DisableSubclassingMeta(GrammaredSequenceMeta):
-    def __new__(mcs, name, bases, dct):
-        for b in bases:
-            if isinstance(b, DisableSubclassingMeta):
-                raise TypeError("Subclassing disabled for class %s. To create"
-                                " a custom sequence class, inherit directly"
-                                " from skbio.sequence.%s" %
-                                (b.__name__, GrammaredSequence.__name__))
-        return super(DisableSubclassingMeta, mcs).__new__(mcs, name, bases,
-                                                          dict(dct))
-
-
 class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
     """Store sequence data conforming to a character set.
 
@@ -121,7 +105,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
 
     Examples
     --------
-
     Note in the example below that properties either need to be static or
     use skbio's `classproperty` decorator.
 
@@ -170,20 +153,29 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
     0 XXXXXX
 
     """
+
     __validation_mask = None
     __degenerate_codes = None
     __definite_char_codes = None
     __gap_codes = None
+    __noncanonical_codes = None
+    __degenerate_hash = None
+    __degen_nonca_hash = None
+    __gap_hash = None
+    __definite_hash = None
 
     @classproperty
     def _validation_mask(cls):
         # TODO These masks could be defined (as literals) on each concrete
         # object. For now, memoize!
         if cls.__validation_mask is None:
-            as_bytes = ''.join(cls.alphabet).encode('ascii')
-            cls.__validation_mask = np.invert(np.bincount(
-                np.frombuffer(as_bytes, dtype=np.uint8),
-                minlength=cls._number_of_extended_ascii_codes).astype(bool))
+            as_bytes = "".join(cls.alphabet).encode("ascii")
+            cls.__validation_mask = np.invert(
+                np.bincount(
+                    np.frombuffer(as_bytes, dtype=np.uint8),
+                    minlength=cls._num_extended_ascii_codes,
+                ).astype(bool)
+            )
         return cls.__validation_mask
 
     @classproperty
@@ -197,8 +189,7 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
     def _definite_char_codes(cls):
         if cls.__definite_char_codes is None:
             definite_chars = cls.definite_chars
-            cls.__definite_char_codes = np.asarray(
-                [ord(d) for d in definite_chars])
+            cls.__definite_char_codes = np.asarray([ord(d) for d in definite_chars])
         return cls.__definite_char_codes
 
     @classproperty
@@ -209,7 +200,41 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         return cls.__gap_codes
 
     @classproperty
-    @stable(as_of='0.4.0')
+    def _noncanonical_codes(cls):
+        if cls.__noncanonical_codes is None:
+            noncanonical_chars = cls.noncanonical_chars
+            cls.__noncanonical_codes = np.asarray([ord(c) for c in noncanonical_chars])
+        return cls.__noncanonical_codes
+
+    @classproperty
+    def _degenerate_hash(cls):
+        if cls.__degenerate_hash is None:
+            cls.__degenerate_hash = np.zeros((Sequence._num_ascii_codes,), dtype=bool)
+            cls.__degenerate_hash[cls._degenerate_codes] = True
+        return cls.__degenerate_hash
+
+    @classproperty
+    def _degen_nonca_hash(cls):
+        if cls.__degen_nonca_hash is None:
+            cls.__degen_nonca_hash = cls._degenerate_hash.copy()
+            cls.__degen_nonca_hash[cls._noncanonical_codes] = True
+        return cls.__degen_nonca_hash
+
+    @classproperty
+    def _gap_hash(cls):
+        if cls.__gap_hash is None:
+            cls.__gap_hash = np.zeros((Sequence._num_ascii_codes,), dtype=bool)
+            cls.__gap_hash[cls._gap_codes] = True
+        return cls.__gap_hash
+
+    @classproperty
+    def _definite_hash(cls):
+        if cls.__definite_hash is None:
+            cls.__definite_hash = np.zeros((Sequence._num_ascii_codes,), dtype=bool)
+            cls.__definite_hash[cls._definite_char_codes] = True
+        return cls.__definite_hash
+
+    @classproperty
     def alphabet(cls):
         """Return valid characters.
 
@@ -225,7 +250,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
 
     @abstractproperty
     @classproperty
-    @stable(as_of='0.4.0')
     def gap_chars(cls):
         """Return characters defined as gaps.
 
@@ -239,7 +263,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
 
     @abstractproperty
     @classproperty
-    @experimental(as_of='0.4.1')
     def default_gap_char(cls):
         """Gap character to use when constructing a new gapped sequence.
 
@@ -256,7 +279,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         raise NotImplementedError
 
     @classproperty
-    @stable(as_of='0.4.0')
     def degenerate_chars(cls):
         """Return degenerate characters.
 
@@ -269,8 +291,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         return set(cls.degenerate_map)
 
     @classproperty
-    @deprecated(as_of='0.5.0', until='0.6.0',
-                reason='Renamed to definite_chars')
     def nondegenerate_chars(cls):
         """Return non-degenerate characters.
 
@@ -279,12 +299,23 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         set
             Non-degenerate characters.
 
-        """
+        Warnings
+        --------
+        ``nondegenerate_chars`` is deprecated as of ``0.5.0``. It has been renamed to
+        ``definite_chars``.
+
+        See Also
+        --------
+        definite_chars
+
+        """  # noqa: D416
+        # @deprecated
+        warn("nondegenerate_chars is deprecated as of 0.5.0", DeprecationWarning)
+
         return cls.definite_chars
 
     @abstractproperty
     @classproperty
-    @stable(as_of='0.5.0')
     def definite_chars(cls):
         """Return definite characters.
 
@@ -296,9 +327,20 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         """
         raise NotImplementedError
 
+    @classproperty
+    def noncanonical_chars(cls):
+        """Return non-canonical characters.
+
+        Returns
+        -------
+        set
+            Non-canonical characters.
+
+        """
+        return set()
+
     @abstractproperty
     @classproperty
-    @stable(as_of='0.4.0')
     def degenerate_map(cls):
         """Return mapping of degenerate to definite characters.
 
@@ -311,16 +353,35 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         """
         raise NotImplementedError
 
+    @classproperty
+    def wildcard_char(cls):
+        """Return wildcard character.
+
+        Returns
+        -------
+        str of length 1
+            Wildcard character.
+
+        """
+        return None
+
     @property
     def _motifs(self):
         return _motifs
 
     @overrides(Sequence)
-    def __init__(self, sequence, metadata=None, positional_metadata=None,
-                 interval_metadata=None, lowercase=False, validate=True):
+    def __init__(
+        self,
+        sequence,
+        metadata=None,
+        positional_metadata=None,
+        interval_metadata=None,
+        lowercase=False,
+        validate=True,
+    ):
         super(GrammaredSequence, self).__init__(
-            sequence, metadata, positional_metadata,
-            interval_metadata, lowercase)
+            sequence, metadata, positional_metadata, interval_metadata, lowercase
+        )
 
         if validate:
             self._validate()
@@ -333,23 +394,26 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         # The result is a vector which will propogate counts of invalid
         # numbers and remove counts of valid numbers, so that we need only
         # see if the array is empty to determine validity.
-        invalid_characters = np.bincount(
-            self._bytes, minlength=self._number_of_extended_ascii_codes
-        ) * self._validation_mask
+        invalid_characters = (
+            np.bincount(self._bytes, minlength=self._num_extended_ascii_codes)
+            * self._validation_mask
+        )
         if np.any(invalid_characters):
-            bad = list(np.where(
-                invalid_characters > 0)[0].astype(np.uint8).view('|S1'))
+            bad = list(np.where(invalid_characters > 0)[0].astype(np.uint8).view("|S1"))
             raise ValueError(
                 "Invalid character%s in sequence: %r. \n"
                 "Valid characters: %r\n"
                 "Note: Use `lowercase` if your sequence contains lowercase "
                 "characters not in the sequence's alphabet."
-                % ('s' if len(bad) > 1 else '',
-                   [str(b.tobytes().decode("ascii")) for b in bad] if
-                   len(bad) > 1 else bad[0],
-                   list(self.alphabet)))
+                % (
+                    "s" if len(bad) > 1 else "",
+                    [str(b.tobytes().decode("ascii")) for b in bad]
+                    if len(bad) > 1
+                    else bad[0],
+                    list(self.alphabet),
+                )
+            )
 
-    @stable(as_of='0.4.0')
     def gaps(self):
         """Find positions containing gaps in the biological sequence.
 
@@ -371,9 +435,8 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         array([False, False,  True, False,  True], dtype=bool)
 
         """
-        return np.in1d(self._bytes, self._gap_codes)
+        return self._gap_hash[self._bytes]
 
-    @stable(as_of='0.4.0')
     def has_gaps(self):
         """Determine if the sequence contains one or more gap characters.
 
@@ -398,7 +461,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         # TODO: cache results
         return bool(self.gaps().any())
 
-    @stable(as_of='0.4.0')
     def degenerates(self):
         """Find positions containing degenerate characters in the sequence.
 
@@ -422,9 +484,8 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         array([False, False,  True, False,  True], dtype=bool)
 
         """
-        return np.in1d(self._bytes, self._degenerate_codes)
+        return self._degenerate_hash[self._bytes]
 
-    @stable(as_of='0.4.0')
     def has_degenerates(self):
         """Determine if sequence contains one or more degenerate characters.
 
@@ -455,7 +516,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         # TODO: cache results
         return bool(self.degenerates().any())
 
-    @stable(as_of='0.5.0')
     def definites(self):
         """Find positions containing definite characters in the sequence.
 
@@ -478,10 +538,8 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         array([ True,  True, False,  True, False], dtype=bool)
 
         """
-        return np.in1d(self._bytes, self._definite_char_codes)
+        return self._definite_hash[self._bytes]
 
-    @deprecated(as_of='0.5.0', until='0.6.0',
-                reason='Renamed to definites')
     def nondegenerates(self):
         """Find positions containing non-degenerate characters in the sequence.
 
@@ -491,8 +549,14 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
             Boolean vector where ``True`` indicates a non-degenerate character
             is present at that position in the biological sequence.
 
+        Warnings
+        --------
+        ``nondegenerates`` is deprecated as of ``0.5.0``. It has been renamed to
+        ``definites``.
+
         See Also
         --------
+        definites
         has_definites
         degenerates
 
@@ -503,12 +567,14 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         >>> s.nondegenerates()
         array([ True,  True, False,  True, False], dtype=bool)
 
-        """
+        """  # noqa: D416
+        # @deprecated
+        warn("nondenengerates is deprecated as of 0.5.0.", DeprecationWarning)
+
         return self.definites()
 
-    @stable(as_of='0.5.0')
     def has_definites(self):
-        """Determine if sequence contains one or more definite characters
+        """Determine if sequence contains one or more definite characters.
 
         Returns
         -------
@@ -536,10 +602,8 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         # TODO: cache results
         return bool(self.definites().any())
 
-    @deprecated(as_of='0.5.0', until='0.6.0',
-                reason='Renamed to has_definites')
     def has_nondegenerates(self):
-        """Determine if sequence contains one or more non-degenerate characters
+        """Determine if sequence contains one or more non-degenerate characters.
 
         Returns
         -------
@@ -547,9 +611,15 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
             Indicates whether there are one or more occurrences of
             non-degenerate characters in the biological sequence.
 
+        Warnings
+        --------
+        ``has_nondegenerates`` is deprecated as of ``0.5.0``. It has been renamed to
+        ``has_definites``.
+
         See Also
         --------
         definites
+        has_definites
         degenerates
         has_degenerates
 
@@ -563,11 +633,13 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         >>> t.has_nondegenerates()
         True
 
-        """
+        """  # noqa: D416
         # TODO: cache results
+        # @deprecated
+        warn("has_nondegenerates is deprecated as of 0.5.0", DeprecationWarning)
+
         return self.has_definites()
 
-    @stable(as_of='0.4.0')
     def degap(self):
         """Return a new sequence with gap characters removed.
 
@@ -609,7 +681,6 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         """
         return self[np.invert(self.gaps())]
 
-    @stable(as_of='0.4.0')
     def expand_degenerates(self):
         """Yield all possible definite versions of the sequence.
 
@@ -683,12 +754,12 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
 
         for definite_seq in product(*expansions):
             yield self._constructor(
-                sequence=''.join(definite_seq),
+                sequence="".join(definite_seq),
                 metadata=metadata,
                 positional_metadata=positional_metadata,
-                interval_metadata=self.interval_metadata)
+                interval_metadata=self.interval_metadata,
+            )
 
-    @stable(as_of='0.4.1')
     def to_regex(self, within_capture=False):
         """Return regular expression object that accounts for degenerate chars.
 
@@ -725,19 +796,70 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
         regex_parts = []
         for base in str(self):
             if base in self.degenerate_chars:
-                regex_parts.append('[{0}]'.format(
-                    ''.join(self.degenerate_map[base])))
+                regex_parts.append("[{0}]".format("".join(self.degenerate_map[base])))
             else:
                 regex_parts.append(base)
 
-        regex_string = ''.join(regex_parts)
+        regex_string = "".join(regex_parts)
 
         if within_capture:
-            regex_string = '({})'.format(regex_string)
+            regex_string = "({})".format(regex_string)
 
         return re.compile(regex_string)
 
-    @stable(as_of='0.4.0')
+    def to_definites(self, degenerate="wild", noncanonical=True):
+        """Convert degenerate and noncanonical characters to alternative characters.
+
+        Parameters
+        ----------
+        degenerate : {"wild", "gap", "del", str of length 1}, optional
+            How degenerate/non-canonical characters should be treated: Replace them
+            with the wildcard character ("wild", default), or the default gap character
+            ("gap"), or a user-defined character (str of length 1), or remove them
+            ("del").
+        noncanonical : bool, optional
+            Treat non-canonical characters in the same way as degenerate
+            characters (``True``, default), or leave them as-is (``False``).
+
+        Returns
+        -------
+        GrammaredSequence
+            Converted version of the sequence.
+
+        """
+        errmsg = (
+            f'%s character for sequence type "{self.__class__}" is undefined or '
+            "invalid."
+        )
+
+        if noncanonical:
+            pos = self._degen_nonca_hash[self._bytes]
+        else:
+            pos = self._degenerate_hash[self._bytes]
+
+        if degenerate == "del":
+            seq = self._bytes[np.where(1 - pos)[0]]
+        else:
+            if degenerate == "wild":
+                sub_char = self.wildcard_char
+                if not isinstance(sub_char, str):
+                    raise ValueError(errmsg % "Wildcard")
+            elif degenerate == "gap":
+                sub_char = self.default_gap_char
+            elif isinstance(degenerate, str) and len(degenerate) == 1:
+                if degenerate in self.alphabet:
+                    sub_char = degenerate
+                else:
+                    raise ValueError(
+                        f"Invalid character '{degenerate}' in sequence. Character must "
+                        f"be within sequence alphabet: {self.alphabet}"
+                    )
+            else:
+                raise ValueError('Invalid value for parameter "degenerate".')
+            seq = np.where(pos, ord(sub_char), self._bytes)
+
+        return self._constructor(sequence=seq)
+
     def find_motifs(self, motif_type, min_length=1, ignore=None):
         """Search the biological sequence for motifs.
 
@@ -791,8 +913,10 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
 
         """
         if motif_type not in self._motifs:
-            raise ValueError("Not a known motif (%r) for this sequence (%s)." %
-                             (motif_type, self.__class__.__name__))
+            raise ValueError(
+                "Not a known motif (%r) for this sequence (%s)."
+                % (motif_type, self.__class__.__name__)
+            )
 
         return self._motifs[motif_type](self, min_length, ignore)
 
@@ -804,9 +928,9 @@ class GrammaredSequence(Sequence, metaclass=GrammaredSequenceMeta):
     def _repr_stats(self):
         """Define custom statistics to display in the sequence's repr."""
         stats = super(GrammaredSequence, self)._repr_stats()
-        stats.append(('has gaps', '%r' % self.has_gaps()))
-        stats.append(('has degenerates', '%r' % self.has_degenerates()))
-        stats.append(('has definites', '%r' % self.has_definites()))
+        stats.append(("has gaps", "%r" % self.has_gaps()))
+        stats.append(("has degenerates", "%r" % self.has_degenerates()))
+        stats.append(("has definites", "%r" % self.has_definites()))
         return stats
 
 
