@@ -12,12 +12,12 @@ from collections import defaultdict
 from copy import copy
 
 import numpy as np
+import scipy.sparse as sparse
+from skbio.util import get_rng
 
-from skbio.util._decorator import experimental
-from .__subsample import _subsample_counts_without_replacement
+from biom import subsample as biom_subsample
 
 
-@experimental(as_of="0.4.0")
 def isubsample(items, maximum, minimum=1, buf_size=1000, bin_f=None):
     """Randomly subsample items from bins, without replacement.
 
@@ -107,17 +107,19 @@ def isubsample(items, maximum, minimum=1, buf_size=1000, bin_f=None):
     sampleA ATGGCA
     sampleB ATATATAT
     sampleB ATGGCG
+
     """
     if minimum > maximum:
         raise ValueError("minimum cannot be > maximum.")
     if minimum < 1 or maximum < 1:
         raise ValueError("minimum and maximum must be > 0.")
     if bin_f is None:
+
         def bin_f(x):
             return True
 
     # buffer some random values
-    random_values = np.random.randint(0, sys.maxsize, buf_size)
+    random_values = np.random.randint(0, sys.maxsize, buf_size, dtype=np.int64)
     random_idx = 0
 
     result = defaultdict(list)
@@ -130,7 +132,7 @@ def isubsample(items, maximum, minimum=1, buf_size=1000, bin_f=None):
         random_value = random_values[random_idx]
         random_idx += 1
         if random_idx >= buf_size:
-            random_values = np.random.randint(0, sys.maxsize, buf_size)
+            random_values = np.random.randint(0, sys.maxsize, buf_size, dtype=np.int64)
             random_idx = 0
 
         # push our item on to the heap and drop the smallest if necessary
@@ -147,20 +149,21 @@ def isubsample(items, maximum, minimum=1, buf_size=1000, bin_f=None):
             yield (bin_, item)
 
 
-@experimental(as_of="0.4.0")
-def subsample_counts(counts, n, replace=False):
+def subsample_counts(counts, n, replace=False, seed=None):
     """Randomly subsample from a vector of counts, with or without replacement.
 
     Parameters
     ----------
     counts : 1-D array_like
-        Vector of counts (integers) to randomly subsample from.
+        Vector of counts (integers or floats) to randomly subsample from.
     n : int
         Number of items to subsample from `counts`. Must be less than or equal
         to the sum of `counts`.
     replace : bool, optional
         If ``True``, subsample with replacement. If ``False`` (the default),
         subsample without replacement.
+    seed : int or np.random.Generator, optional
+        A user-provided random seed or random generator instance.
 
     Returns
     -------
@@ -171,8 +174,6 @@ def subsample_counts(counts, n, replace=False):
 
     Raises
     ------
-    TypeError
-        If `counts` cannot be safely converted to an integer datatype.
     ValueError
         If `n` is less than zero or greater than the sum of `counts`
         when `replace=False`.
@@ -225,24 +226,23 @@ def subsample_counts(counts, n, replace=False):
     if n < 0:
         raise ValueError("n cannot be negative.")
 
-    counts = np.asarray(counts)
-    counts = counts.astype(int, casting='safe')
+    # cast to float as that's what the biom subsample method currently requires
+    counts = np.asarray(counts, dtype=float)
 
     if counts.ndim != 1:
         raise ValueError("Only 1-D vectors are supported.")
 
+    # csr_matrix will report ndim of 2 if vector
+    counts = sparse.csr_matrix(counts)
+
     counts_sum = counts.sum()
     if n > counts_sum and not replace:
-        raise ValueError("Cannot subsample more items than exist in input "
-                         "counts vector when `replace=False`.")
+        raise ValueError(
+            "Cannot subsample more items than exist in input "
+            "counts vector when `replace=False`."
+        )
 
-    if replace:
-        probs = counts / counts_sum
-        result = np.random.multinomial(n, probs)
-    else:
-        if counts_sum == n:
-            result = counts
-        else:
-            result = _subsample_counts_without_replacement(counts, n,
-                                                           counts_sum)
-    return result
+    rng = get_rng(seed)
+    biom_subsample(counts, n, replace, rng)
+
+    return np.atleast_1d(counts.astype(int).toarray().squeeze())
