@@ -1,10 +1,9 @@
-"""
-Distance matrices and distance-based statistics (:mod:`skbio.stats.distance`)
-=============================================================================
+r"""Distance matrix-based statistics (:mod:`skbio.stats.distance`)
+==============================================================
 
 .. currentmodule:: skbio.stats.distance
 
-This subpackage provides functionality for serializing, deserializing, and
+This module provides functionality for serializing, deserializing, and
 manipulating dissimilarity and distance matrices in memory. It also contains
 various statistical methods that operate on distance matrices, often relating
 distances (e.g., community distances) to categorical and/or continuous
@@ -12,8 +11,9 @@ variables of interest (e.g., gender or age). Methods are also provided for
 comparing distance matrices (e.g., computing the correlation between two or
 more distance matrices using the Mantel test).
 
-Data Structures: DissimilarityMatrix and DistanceMatrix
--------------------------------------------------------
+
+Data structures
+---------------
 
 This package provides two matrix classes, `DissimilarityMatrix` and
 `DistanceMatrix`. Both classes can store measures of difference/distinction
@@ -57,30 +57,64 @@ Exceptions
 ^^^^^^^^^^
 
 .. autosummary::
-   :toctree:
 
    DissimilarityMatrixError
    DistanceMatrixError
    MissingIDError
 
+
+Distance-based statistics
+-------------------------
+
+In addition to the data structures described above, this package provides the
+following distance-based statistical methods.
+
+Categorical Variable Stats
+^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+.. autosummary::
+   :toctree:
+
+   anosim
+   permanova
+   permdisp
+
+Continuous Variable Stats
+^^^^^^^^^^^^^^^^^^^^^^^^^
+
+.. autosummary::
+   :toctree:
+
+   bioenv
+
+Distance Matrix Comparisons
+^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+.. autosummary::
+   :toctree:
+
+   mantel
+   pwmantel
+
+
 Examples
-^^^^^^^^
+--------
 Assume we have the following delimited text file storing distances between
 three objects with IDs ``a``, ``b``, and ``c``::
 
-    \\ta\\tb\\tc
-    a\\t0.0\\t0.5\\t1.0
-    b\\t0.5\\t0.0\\t0.75
-    c\\t1.0\\t0.75\\t0.0
+    \ta\tb\tc
+    a\t0.0\t0.5\t1.0
+    b\t0.5\t0.0\t0.75
+    c\t1.0\t0.75\t0.0
 
 Load a distance matrix from the file:
 
 >>> from io import StringIO
 >>> from skbio import DistanceMatrix
->>> dm_fh = StringIO("\\ta\\tb\\tc\\n"
-...                  "a\\t0.0\\t0.5\\t1.0\\n"
-...                  "b\\t0.5\\t0.0\\t0.75\\n"
-...                  "c\\t1.0\\t0.75\\t0.0\\n")
+>>> dm_fh = StringIO("\ta\tb\tc\n"
+...                  "a\t0.0\t0.5\t1.0\n"
+...                  "b\t0.5\t0.0\t0.75\n"
+...                  "c\t1.0\t0.75\t0.0\n")
 >>> dm = DistanceMatrix.read(dm_fh)
 >>> print(dm)
 3x3 distance matrix
@@ -140,45 +174,14 @@ Monotonically-increasing integers (cast as strings) will be automatically used:
 >>> dm.ids
 ('0', '1', '2')
 
-Distance-based statistics
--------------------------
-
-In addition to the data structures described above, this package provides the
-following distance-based statistical methods.
-
-Categorical Variable Stats
-^^^^^^^^^^^^^^^^^^^^^^^^^^
-
-.. autosummary::
-   :toctree:
-
-   anosim
-   permanova
-   permdisp
-
-Continuous Variable Stats
-^^^^^^^^^^^^^^^^^^^^^^^^^
-
-.. autosummary::
-   :toctree:
-
-   bioenv
-
-Distance Matrix Comparisons
-^^^^^^^^^^^^^^^^^^^^^^^^^^^
-
-.. autosummary::
-   :toctree:
-
-   mantel
-   pwmantel
 
 References
 ----------
 .. [1] Faith, D. P. (1992). "Conservation evaluation and phylogenetic
    diversity".
 
-"""
+
+"""  # noqa: D407, D205, D415
 
 # ----------------------------------------------------------------------------
 # Copyright (c) 2013--, scikit-bio development team.
@@ -188,15 +191,31 @@ References
 # The full license is in the file LICENSE.txt, distributed with this software.
 # ----------------------------------------------------------------------------
 
-from ._base import (DissimilarityMatrixError, DistanceMatrixError,
-                    MissingIDError, DissimilarityMatrix, DistanceMatrix,
-                    randdm)
+from ._base import (
+    DissimilarityMatrixError,
+    DistanceMatrixError,
+    MissingIDError,
+    DissimilarityMatrix,
+    DistanceMatrix,
+    randdm,
+)
 from ._bioenv import bioenv
 from ._anosim import anosim
 from ._permanova import permanova
 from ._mantel import mantel, pwmantel
 from ._permdisp import permdisp
 
-__all__ = ['DissimilarityMatrixError', 'DistanceMatrixError', 'MissingIDError',
-           'DissimilarityMatrix', 'DistanceMatrix', 'randdm', 'anosim',
-           'permanova', 'bioenv', 'mantel', 'pwmantel', 'permdisp']
+__all__ = [
+    "DissimilarityMatrixError",
+    "DistanceMatrixError",
+    "MissingIDError",
+    "DissimilarityMatrix",
+    "DistanceMatrix",
+    "randdm",
+    "anosim",
+    "permanova",
+    "bioenv",
+    "mantel",
+    "pwmantel",
+    "permdisp",
+]
