@@ -14,12 +14,10 @@ from scipy.spatial.distance import pdist
 from scipy.stats import spearmanr
 
 from skbio.stats.distance import DistanceMatrix
-from skbio.util._decorator import experimental
 
 
-@experimental(as_of="0.4.0")
 def bioenv(distance_matrix, data_frame, columns=None):
-    """Find subset of variables maximally correlated with distances.
+    r"""Find subset of variables maximally correlated with distances.
 
     Finds subsets of variables whose Euclidean distances (after scaling the
     variables; see Notes section below for details) are maximally
@@ -144,7 +142,7 @@ def bioenv(distance_matrix, data_frame, columns=None):
     pH, Elevation     2     0.714286
 
     We see that in this simple example, pH alone is maximally rank-correlated
-    with the community distances (:math:`\\rho=0.771517`).
+    with the community distances (:math:`\rho=0.771517`).
 
     """
     if not isinstance(distance_matrix, DistanceMatrix):
@@ -170,15 +168,16 @@ def bioenv(distance_matrix, data_frame, columns=None):
     vars_df = data_frame.reindex(distance_matrix.ids, axis=0).loc[:, columns]
 
     if vars_df.isnull().any().any():
-        raise ValueError("One or more IDs in the distance matrix are not "
-                         "in the data frame, or there is missing data in the "
-                         "data frame.")
+        raise ValueError(
+            "One or more IDs in the distance matrix are not "
+            "in the data frame, or there is missing data in the "
+            "data frame."
+        )
 
     try:
         vars_df = vars_df.astype(float)
     except ValueError:
-        raise TypeError("All specified columns in the data frame must be "
-                        "numeric.")
+        raise TypeError("All specified columns in the data frame must be " "numeric.")
 
     # Scale the vars and extract the underlying numpy array from the data
     # frame. We mainly do this for performance as we'll be taking subsets of
@@ -192,16 +191,15 @@ def bioenv(distance_matrix, data_frame, columns=None):
 
     # For each subset size, store the best combination of variables:
     #     (string identifying best vars, subset size, rho)
-    max_rhos = np.empty(num_vars, dtype=[('vars', object),
-                                         ('size', int),
-                                         ('correlation', float)])
+    max_rhos = np.empty(
+        num_vars, dtype=[("vars", object), ("size", int), ("correlation", float)]
+    )
     for subset_size in range(1, num_vars + 1):
         max_rho = None
         for subset_idxs in combinations(var_idxs, subset_size):
             # Compute Euclidean distances using the current subset of
             # variables. pdist returns the distances in condensed form.
-            vars_dm_flat = pdist(vars_array[:, subset_idxs],
-                                 metric='euclidean')
+            vars_dm_flat = pdist(vars_array[:, subset_idxs], metric="euclidean")
             rho = spearmanr(dm_flat, vars_dm_flat)[0]
 
             # If there are ties for the best rho at a given subset size, choose
@@ -209,10 +207,10 @@ def bioenv(distance_matrix, data_frame, columns=None):
             if max_rho is None or rho > max_rho[0]:
                 max_rho = (rho, subset_idxs)
 
-        vars_label = ', '.join([columns[i] for i in max_rho[1]])
+        vars_label = ", ".join([columns[i] for i in max_rho[1]])
         max_rhos[subset_size - 1] = (vars_label, subset_size, max_rho[0])
 
-    return pd.DataFrame.from_records(max_rhos, index='vars')
+    return pd.DataFrame.from_records(max_rhos, index="vars")
 
 
 def _scale(df):
@@ -228,6 +226,8 @@ def _scale(df):
     df /= df.std()
 
     if df.isnull().any().any():
-        raise ValueError("Column(s) in the data frame could not be scaled, "
-                         "likely because the column(s) had no variance.")
+        raise ValueError(
+            "Column(s) in the data frame could not be scaled, "
+            "likely because the column(s) had no variance."
+        )
     return df
