@@ -25,6 +25,7 @@ from skbio.stats.distance._mantel import _mantel_stats_spearman
 from skbio.stats.distance._cutils import mantel_perm_pearsonr_cy
 from skbio.stats.distance._utils import distmat_reorder_condensed
 from skbio.util import get_data_path, assert_data_frame_almost_equal
+from skbio.util._testing import _data_frame_to_default_int_type
 
 
 class MantelTestData(TestCase):
@@ -74,7 +75,7 @@ class InternalMantelTests(MantelTestData):
         perm_order = np.asarray([[2, 1, 0],
                                  [2, 0, 1],
                                  [0, 2, 1],
-                                 [2, 0, 1]], dtype=int)
+                                 [2, 0, 1]], dtype=np.intp)
         xmean = 2.0
         normxm = 1.4142135623730951
         ym_normalized = np.asarray([-0.80178373, 0.26726124, 0.53452248])
@@ -106,7 +107,7 @@ class InternalMantelTests(MantelTestData):
                                  [4, 3, 2, 5, 0, 1],
                                  [2, 5, 3, 1, 0, 4],
                                  [3, 5, 4, 1, 2, 0],
-                                 [4, 3, 5, 2, 0, 1]], dtype=int)
+                                 [4, 3, 5, 2, 0, 1]], dtype=np.intp)
         xmean = 0.6953921578226
         normxm = 0.3383126690576294
         ym_normalized = np.asarray([-0.4999711, 0.24980825, -0.29650504,
@@ -159,7 +160,7 @@ class InternalMantelTests(MantelTestData):
                                  [1, 2, 5, 4, 0, 3],
                                  [5, 4, 0, 1, 3, 2],
                                  [3, 0, 1, 5, 4, 2],
-                                 [5, 0, 2, 3, 1, 4]], dtype=int)
+                                 [5, 0, 2, 3, 1, 4]], dtype=np.intp)
 
         ym_normalized = ym/normym
 
@@ -495,25 +496,39 @@ class PairwiseMantelTests(MantelTestData):
         self.min_dms = (self.minx_dm, self.miny_dm, self.minz_dm)
 
         self.exp_results_minimal = pd.read_csv(
-            get_data_path('pwmantel_exp_results_minimal.txt'), sep='\t',
-            index_col=(0, 1))
+            get_data_path('pwmantel_exp_results_minimal.txt'),
+            sep='\t',
+            index_col=(0, 1)
+        )
+        _data_frame_to_default_int_type(self.exp_results_minimal)
 
         self.exp_results_minimal_with_labels = pd.read_csv(
             get_data_path('pwmantel_exp_results_minimal_with_labels.txt'),
-            sep='\t', index_col=(0, 1))
+            sep='\t',
+            index_col=(0, 1)
+        )
+        _data_frame_to_default_int_type(self.exp_results_minimal_with_labels)
 
         self.exp_results_duplicate_dms = pd.read_csv(
             get_data_path('pwmantel_exp_results_duplicate_dms.txt'),
-            sep='\t', index_col=(0, 1))
+            sep='\t',
+            index_col=(0, 1)
+        )
+        _data_frame_to_default_int_type(self.exp_results_duplicate_dms)
 
         self.exp_results_na_p_value = pd.read_csv(
             get_data_path('pwmantel_exp_results_na_p_value.txt'),
-            sep='\t', index_col=(0, 1))
+            sep='\t',
+            index_col=(0, 1)
+        )
+        _data_frame_to_default_int_type(self.exp_results_na_p_value)
 
         self.exp_results_reordered_distance_matrices = pd.read_csv(
-            get_data_path('pwmantel_exp_results_reordered_distance_matrices'
-                          '.txt'),
-            sep='\t', index_col=(0, 1))
+            get_data_path('pwmantel_exp_results_reordered_distance_matrices.txt'),
+            sep='\t',
+            index_col=(0, 1)
+        )
+        _data_frame_to_default_int_type(self.exp_results_reordered_distance_matrices)
 
         self.exp_results_dm_dm2 = pd.read_csv(
             get_data_path('pwmantel_exp_results_dm_dm2.txt'),
