@@ -14,12 +14,12 @@ import numpy.testing as npt
 import pandas as pd
 from pandas.testing import assert_series_equal
 from scipy.stats import f_oneway
-import hdmedians as hd
 
 from skbio import DistanceMatrix
 from skbio.stats.ordination import pcoa
 from skbio.stats.distance import permdisp
 from skbio.stats.distance._permdisp import _compute_groups
+from skbio.stats.distance._cutils import geomedian_axis_one
 from skbio.util import get_data_path
 
 
@@ -245,10 +245,10 @@ class testPERMDISP(TestCase):
         pval = obs['p-value']
         np.isnan(pval)
 
-    def test_hdmedians(self):
+    def test_geomedian(self):
         exp = np.array([2.01956244, 1.53164546, 2.60571752, 0.91424179,
                         1.76214416, 1.69943057])
-        obs = np.array(hd.geomedian(self.eq_mat.data))
+        obs = np.array(geomedian_axis_one(self.eq_mat.data))
         npt.assert_almost_equal(obs, exp, decimal=6)
 
     def test_confirm_betadispr_results(self):
@@ -277,6 +277,24 @@ class testPERMDISP(TestCase):
 
         self.assert_series_equal(exp_cen_mp, obs_cen_mp)
 
+    def test_call_via_series(self):
+        # test https://github.com/scikit-bio/scikit-bio/issues/1877
+        # actual issue is with _base._preprocess_input_sng but permdisp is
+        # indirectly affected
+        dm = DistanceMatrix.read(get_data_path('frameSeries_dm.tsv'))
+        grouping = pd.read_csv(get_data_path("frameSeries_grouping.tsv"),
+                               sep="\t", index_col=0)
+
+        np.random.seed(0)
+        obs_frame = permdisp(dm, grouping, column='tumor')
+
+        np.random.seed(0)
+        obs_series = permdisp(dm, grouping['tumor'])
+
+        # in principle, both tests - if seed is the same - should return the
+        # exact same results. However, they don't for the current example ...
+        self.assert_series_equal(obs_frame, obs_series)
+
 
 if __name__ == '__main__':
     main()
