@@ -1,5 +1,4 @@
-r"""
-Gradient analyses (:mod:`skbio.stats.gradient`)
+r"""Gradient analyses (:mod:`skbio.stats.gradient`)
 ===============================================
 
 .. currentmodule:: skbio.stats.gradient
@@ -83,7 +82,9 @@ Control
 [ 3.52199973  2.29597001  3.20309816]
 >>> print(trajectory_results.categories[0].groups[0].info)
 {'avg': 3.007022633956606}
-"""
+
+
+"""  # noqa: D205, D415
 
 # ----------------------------------------------------------------------------
 # Copyright (c) 2013--, scikit-bio development team.
@@ -101,12 +102,9 @@ import numpy as np
 from natsort import realsorted
 from scipy.stats import f_oneway
 
-from skbio.util._decorator import experimental
-
 
 def _weight_by_vector(trajectories, w_vector):
-    r"""weights the values of `trajectories` given a weighting vector
-    `w_vector`.
+    r"""Weight the values of `trajectories` given a weighting vector `w_vector`.
 
     Each value in `trajectories` will be weighted by the 'rate of change'
     to 'optimal rate of change' ratio. The 'rate of change' of a vector
@@ -135,11 +133,14 @@ def _weight_by_vector(trajectories, w_vector):
         If `w_vector` is not a gradient
     TypeError
         If `trajectories` and `w_vector` are not iterables
+
     """
     try:
         if len(trajectories) != len(w_vector):
-            raise ValueError("trajectories (%d) & w_vector (%d) must be equal "
-                             "lengths" % (len(trajectories), len(w_vector)))
+            raise ValueError(
+                "trajectories (%d) & w_vector (%d) must be equal "
+                "lengths" % (len(trajectories), len(w_vector))
+            )
     except TypeError:
         raise TypeError("trajectories and w_vector must be iterables")
 
@@ -157,22 +158,23 @@ def _weight_by_vector(trajectories, w_vector):
     # Reflects the expected gradient between subsequent values in w_vector
     # the first value isn't weighted so subtract one from the number of
     # elements
-    optimal_gradient = total_length/(len(w_vector)-1)
+    optimal_gradient = total_length / (len(w_vector) - 1)
 
     # for all elements apply the weighting function
     for i, idx in enumerate(trajectories.index):
         # Skipping the first element is it doesn't need to be weighted
         if i != 0:
             trajectories.loc[idx] = (
-                trajectories.loc[idx] * optimal_gradient /
-                np.abs((w_vector[i] - w_vector[i-1]))
+                trajectories.loc[idx]
+                * optimal_gradient
+                / np.abs((w_vector.iloc[i] - w_vector.iloc[i - 1]))
             )
 
-    return trajectories.astype('float64')
+    return trajectories.astype("float64")
 
 
 def _ANOVA_trajectories(category, res_by_group):
-    r"""Run ANOVA over `res_by_group`
+    r"""Run ANOVA over `res_by_group`.
 
     If ANOVA cannot be run in the current category (because either there is
     only one group in category or there is a group with only one member)
@@ -184,25 +186,29 @@ def _ANOVA_trajectories(category, res_by_group):
     CategoryResults
         An instance of CategoryResults holding the results of the trajectory
         analysis applied on `category`
+
     """
     # If there is only one group under category we cannot run ANOVA
     if len(res_by_group) == 1:
-        return CategoryResults(category, None, None,
-                               'Only one value in the group.')
+        return CategoryResults(category, None, None, "Only one value in the group.")
     # Check if groups can be tested using ANOVA. ANOVA testing requires
     # all elements to have at least size greater to one.
     values = [res.trajectory.astype(float) for res in res_by_group]
     if any([len(value) == 1 for value in values]):
-        return CategoryResults(category, None, None,
-                               'This group can not be used. All groups '
-                               'should have more than 1 element.')
+        return CategoryResults(
+            category,
+            None,
+            None,
+            "This group can not be used. All groups "
+            "should have more than 1 element.",
+        )
     # We are ok to run ANOVA
     _, p_val = f_oneway(*values)
     return CategoryResults(category, p_val, res_by_group, None)
 
 
 class GroupResults:
-    """Store the trajectory results of a group of a metadata category
+    """Store the trajectory results of a group of a metadata category.
 
     Attributes
     ----------
@@ -220,18 +226,16 @@ class GroupResults:
 
     """
 
-    @experimental(as_of="0.4.0")
     def __init__(self, name, trajectory, mean, info, message):
+        """Construct all the necessary attributes for the GroupResults object."""
         self.name = name
         self.trajectory = trajectory
         self.mean = mean
         self.info = info
         self.message = message
 
-    @experimental(as_of="0.4.0")
     def to_files(self, out_f, raw_f):
-        r"""Save the trajectory analysis results for a category group to files
-        in text format.
+        r"""Save trajectory analysis results for a category group to text format files.
 
         Parameters
         ----------
@@ -243,23 +247,23 @@ class GroupResults:
             File-like object to write trajectories trajectory values. Must have
             a `write` method. It is the caller's responsibility to close
             `out_f` when done (if necessary)
+
         """
-        out_f.write('For group "%s", the group means is: %f\n'
-                    % (self.name, self.mean))
+        out_f.write('For group "%s", the group means is: %f\n' % (self.name, self.mean))
         raw_f.write('For group "%s":\n' % self.name)
 
         if self.message:
-            out_f.write('%s\n' % self.message)
-            raw_f.write('%s\n' % self.message)
+            out_f.write("%s\n" % self.message)
+            raw_f.write("%s\n" % self.message)
 
-        out_f.write('The info is: %s\n'
-                    % sorted(((k, v) for k, v in self.info.items())))
-        raw_f.write('The trajectory is:\n[%s]\n'
-                    % ", ".join(map(str, self.trajectory)))
+        out_f.write(
+            "The info is: %s\n" % sorted(((k, v) for k, v in self.info.items()))
+        )
+        raw_f.write("The trajectory is:\n[%s]\n" % ", ".join(map(str, self.trajectory)))
 
 
 class CategoryResults:
-    """Store the trajectory results of a metadata category
+    """Store the trajectory results of a metadata category.
 
     Attributes
     ----------
@@ -274,17 +278,15 @@ class CategoryResults:
 
     """
 
-    @experimental(as_of="0.4.0")
     def __init__(self, category, probability, groups, message):
+        """Construct all the necessary attributes for the CategoryResults object."""
         self.category = category
         self.probability = probability
         self.groups = groups
         self.message = message
 
-    @experimental(as_of="0.4.0")
     def to_files(self, out_f, raw_f):
-        r"""Save the trajectory analysis results for a category to files in
-        text format.
+        r"""Save trajectory analysis results for a category to files in text format.
 
         Parameters
         ----------
@@ -296,20 +298,21 @@ class CategoryResults:
             File-like object to write trajectory raw values. Must have a
             `write` method. It is the caller's responsibility to close `out_f`
             when done (if necessary)
+
         """
         if self.probability is None:
-            out_f.write('Grouped by "%s": %s\n'
-                        % (self.category, self.message))
+            out_f.write('Grouped by "%s": %s\n' % (self.category, self.message))
         else:
-            out_f.write('Grouped by "%s", probability: %f\n'
-                        % (self.category, self.probability))
+            out_f.write(
+                'Grouped by "%s", probability: %f\n' % (self.category, self.probability)
+            )
             raw_f.write('Grouped by "%s"\n' % self.category)
             for group in self.groups:
                 group.to_files(out_f, raw_f)
 
 
 class GradientANOVAResults:
-    """Store the trajectory results
+    """Store the trajectory results.
 
     Attributes
     ----------
@@ -322,13 +325,12 @@ class GradientANOVAResults:
 
     """
 
-    @experimental(as_of="0.4.0")
     def __init__(self, algorithm, weighted, categories):
+        """Construct all the attributes for the GradientANOVAResults object."""
         self.algorithm = algorithm
         self.weighted = weighted
         self.categories = categories
 
-    @experimental(as_of="0.4.0")
     def to_files(self, out_f, raw_f):
         r"""Save the trajectory analysis results to files in text format.
 
@@ -342,25 +344,26 @@ class GradientANOVAResults:
             File-like object to write trajectories raw values. Must have a
             `write` method. It is the caller's responsibility to close `out_f`
             when done (if necessary)
+
         """
-        out_f.write('Trajectory algorithm: %s\n' % self.algorithm)
-        raw_f.write('Trajectory algorithm: %s\n' % self.algorithm)
+        out_f.write("Trajectory algorithm: %s\n" % self.algorithm)
+        raw_f.write("Trajectory algorithm: %s\n" % self.algorithm)
 
         if self.weighted:
-            out_f.write('** This output is weighted **\n')
-            raw_f.write('** This output is weighted **\n')
+            out_f.write("** This output is weighted **\n")
+            raw_f.write("** This output is weighted **\n")
 
-        out_f.write('\n')
-        raw_f.write('\n')
+        out_f.write("\n")
+        raw_f.write("\n")
 
         for cat_results in self.categories:
             cat_results.to_files(out_f, raw_f)
-            out_f.write('\n')
-            raw_f.write('\n')
+            out_f.write("\n")
+            raw_f.write("\n")
 
 
 class GradientANOVA:
-    r"""Base class for the Trajectory algorithms
+    r"""Base class for the Trajectory algorithms.
 
     Parameters
     ----------
@@ -396,14 +399,23 @@ class GradientANOVA:
         If `weighted` is True and the values under `sort_category` are not
         numerical
         If `coords` and `metadata_map` does not have samples in common
+
     """
+
     # Should be defined by the derived classes
     _alg_name = None
 
-    @experimental(as_of="0.4.0")
-    def __init__(self, coords, prop_expl, metadata_map,
-                 trajectory_categories=None, sort_category=None, axes=3,
-                 weighted=False):
+    def __init__(
+        self,
+        coords,
+        prop_expl,
+        metadata_map,
+        trajectory_categories=None,
+        sort_category=None,
+        axes=3,
+        weighted=False,
+    ):
+        """Construct all the necessary attributes for the GradientANOVA object."""
         if not trajectory_categories:
             # If trajectory_categories is not provided, use all the categories
             # present in the metadata map
@@ -412,25 +424,26 @@ class GradientANOVA:
             # Check that trajectory_categories are in metadata_map
             for category in trajectory_categories:
                 if category not in metadata_map:
-                    raise ValueError("Category %s not present in metadata."
-                                     % category)
+                    raise ValueError("Category %s not present in metadata." % category)
 
         # Check that sort_categories is in metadata_map
         if sort_category and sort_category not in metadata_map:
-            raise ValueError("Sort category %s not present in metadata."
-                             % sort_category)
+            raise ValueError(
+                "Sort category %s not present in metadata." % sort_category
+            )
 
         if axes == 0:
             # If axes == 0, we should compute the trajectories for all axes
             axes = len(prop_expl)
         elif axes > len(prop_expl) or axes < 0:
             # Axes should be 0 <= axes <= len(prop_expl)
-            raise ValueError("axes should be between 0 and the max number of "
-                             "axes available (%d), found: %d "
-                             % (len(prop_expl), axes))
+            raise ValueError(
+                "axes should be between 0 and the max number of "
+                "axes available (%d), found: %d " % (len(prop_expl), axes)
+            )
 
         # Restrict coordinates to those axes that we actually need to compute
-        self._coords = coords.loc[:, :axes-1]
+        self._coords = coords.loc[:, : axes - 1]
         self._prop_expl = prop_expl[:axes]
         self._metadata_map = metadata_map
         self._weighted = weighted
@@ -446,26 +459,31 @@ class GradientANOVA:
         self._weighting_vector = None
         if weighted:
             if not sort_category:
-                raise ValueError("You should provide a sort category if you "
-                                 "want to weight the trajectories")
+                raise ValueError(
+                    "You should provide a sort category if you "
+                    "want to weight the trajectories"
+                )
             try:
-                self._weighting_vector = \
-                    self._metadata_map[sort_category].astype(np.float64)
+                self._weighting_vector = self._metadata_map[sort_category].astype(
+                    np.float64
+                )
             except ValueError:
                 raise ValueError("The sorting category must be numeric")
 
         # Initialize the message buffer
         self._message_buffer = []
 
-    @experimental(as_of="0.4.0")
     def get_trajectories(self):
-        r"""Compute the trajectories for each group in each category and run
-        ANOVA over the results to test group independence.
+        r"""Compute the trajectories for each group and category and run ANOVA.
+
+        More specifically, compute the trajectories for each group in each category
+        and run ANOVA over the results to test group independence.
 
         Returns
         -------
         GradientANOVAResults
             An instance of GradientANOVAResults holding the results.
+
         """
         result = GradientANOVAResults(self._alg_name, self._weighted, [])
         # Loop through all the categories that we should compute
@@ -476,20 +494,21 @@ class GradientANOVA:
             res_by_group = []
             for group in sorted(cat_groups, key=lambda k: str(k)):
                 res_by_group.append(
-                    self._get_group_trajectories(group, cat_groups[group]))
+                    self._get_group_trajectories(group, cat_groups[group])
+                )
 
             result.categories.append(_ANOVA_trajectories(cat, res_by_group))
 
         return result
 
     def _normalize_samples(self):
-        r"""Ensures that `self._coords` and `self._metadata_map` have the same
-        sample ids
+        r"""Ensure `self._coords` and `self._metadata_map` have the same sample ids.
 
         Raises
         ------
         ValueError
             If `coords` and `metadata_map` does not have samples in common
+
         """
         # Figure out the sample ids in common
         coords_sample_ids = set(self._coords.index)
@@ -498,8 +517,7 @@ class GradientANOVA:
 
         # Check if they actually have sample ids in common
         if not sample_ids:
-            raise ValueError("Coordinates and metadata map had no samples "
-                             "in common")
+            raise ValueError("Coordinates and metadata map had no samples " "in common")
 
         # pandas no longer allows use of set with .loc
         sample_ids = list(sample_ids)
@@ -512,8 +530,7 @@ class GradientANOVA:
             self._metadata_map = self._metadata_map.loc[sample_ids]
 
     def _make_groups(self, trajectory_categories, sort_category):
-        r"""Groups the sample ids in `self._metadata_map` by the values in
-        `trajectory_categories`
+        r"""Group sample ids in `self._metadata_map` by `trajectory_categories` values.
 
         Creates `self._groups`, a dictionary keyed by category and values are
         dictionaries in which the keys represent the group name within the
@@ -530,13 +547,16 @@ class GradientANOVA:
             Default: None, compute all of them
         sort_category : str or None
             The category from self._metadata_map to use to sort groups
+
         """
         # If sort_category is provided, we used the value of such category to
         # sort. Otherwise, we use the sample id.
         if sort_category:
+
             def sort_val(sid):
                 return self._metadata_map[sort_category][sid]
         else:
+
             def sort_val(sid):
                 return sid
 
@@ -548,8 +568,7 @@ class GradientANOVA:
                 self._groups[cat][g] = realsorted(df.index, key=sort_val)
 
     def _get_group_trajectories(self, group_name, sids):
-        r"""Compute the trajectory results for `group_name` containing the
-        samples `sids`.
+        r"""Compute trajectory results for `group_name` containing the samples `sids`.
 
         Weights the data if `self._weighted` is True and ``len(sids) > 1``
 
@@ -569,6 +588,7 @@ class GradientANOVA:
         ------
         RuntimeError
             If sids is an empty list
+
         """
         # We multiply the coord values with the prop_expl
         trajectories = self._coords.loc[sids] * self._prop_expl
@@ -578,27 +598,30 @@ class GradientANOVA:
             # never happen. The only way this can happen is if the user
             # directly calls this method, which shouldn't be done
             # (that's why the method is private)
-            raise RuntimeError("No samples to process, an empty list cannot "
-                               "be processed")
+            raise RuntimeError(
+                "No samples to process, an empty list cannot " "be processed"
+            )
 
         # The weighting can only be done over trajectories with a length
         # greater than 1
         if self._weighted and len(sids) > 1:
             trajectories_copy = deepcopy(trajectories)
             try:
-                trajectories = _weight_by_vector(trajectories_copy,
-                                                 self._weighting_vector[sids])
+                trajectories = _weight_by_vector(
+                    trajectories_copy, self._weighting_vector[sids]
+                )
             except (FloatingPointError, ValueError):
-                self._message_buffer.append("Could not weight group, no "
-                                            "gradient in the the "
-                                            "weighting vector.\n")
+                self._message_buffer.append(
+                    "Could not weight group, no "
+                    "gradient in the the "
+                    "weighting vector.\n"
+                )
                 trajectories = trajectories_copy
 
-        return self._compute_trajectories_results(group_name,
-                                                  trajectories.loc[sids])
+        return self._compute_trajectories_results(group_name, trajectories.loc[sids])
 
     def _compute_trajectories_results(self, group_name, trajectories):
-        r"""Do the actual trajectories computation over trajectories
+        r"""Do the actual trajectories computation over trajectories.
 
         Parameters
         ----------
@@ -611,13 +634,13 @@ class GradientANOVA:
         ------
         NotImplementedError
             This is the base class
+
         """
-        raise NotImplementedError("No algorithm is implemented on the base "
-                                  "class.")
+        raise NotImplementedError("No algorithm is implemented on the base " "class.")
 
 
 class AverageGradientANOVA(GradientANOVA):
-    r"""Perform trajectory analysis using the RMS average algorithm
+    r"""Perform trajectory analysis using the RMS average algorithm.
 
     For each group in a category, it computes the average point among the
     samples in such group and then computes the norm of each sample from the
@@ -626,12 +649,13 @@ class AverageGradientANOVA(GradientANOVA):
     See Also
     --------
     GradientANOVA
+
     """
 
-    _alg_name = 'avg'
+    _alg_name = "avg"
 
     def _compute_trajectories_results(self, group_name, trajectories):
-        r"""Do the actual trajectory computation over trajectories
+        r"""Do the actual trajectory computation over trajectories.
 
         Parameters
         ----------
@@ -645,25 +669,29 @@ class AverageGradientANOVA(GradientANOVA):
         GroupResults
             The trajectory results for `group_name` using the average
             trajectories method
+
         """
         center = np.average(trajectories, axis=0)
         if len(trajectories) == 1:
             trajectory = np.array([np.linalg.norm(center)])
-            calc = {'avg': trajectory[0]}
+            calc = {"avg": trajectory[0]}
         else:
-            trajectory = np.array([np.linalg.norm(row[1].to_numpy() - center)
-                                   for row in trajectories.iterrows()])
-            calc = {'avg': np.average(trajectory)}
+            trajectory = np.array(
+                [
+                    np.linalg.norm(row[1].to_numpy() - center)
+                    for row in trajectories.iterrows()
+                ]
+            )
+            calc = {"avg": np.average(trajectory)}
 
-        msg = ''.join(self._message_buffer) if self._message_buffer else None
+        msg = "".join(self._message_buffer) if self._message_buffer else None
         # Reset the message buffer
         self._message_buffer = []
-        return GroupResults(group_name, trajectory, np.mean(trajectory),
-                            calc, msg)
+        return GroupResults(group_name, trajectory, np.mean(trajectory), calc, msg)
 
 
 class TrajectoryGradientANOVA(GradientANOVA):
-    r"""Perform trajectory analysis using the RMS trajectory algorithm
+    r"""Perform trajectory analysis using the RMS trajectory algorithm.
 
     For each group in a category, each component of the result trajectory is
     computed as taking the sorted list of samples in the group and taking the
@@ -673,12 +701,13 @@ class TrajectoryGradientANOVA(GradientANOVA):
     See Also
     --------
     GradientANOVA
+
     """
 
-    _alg_name = 'trajectory'
+    _alg_name = "trajectory"
 
     def _compute_trajectories_results(self, group_name, trajectories):
-        r"""Do the actual trajectory computation over trajectories
+        r"""Do the actual trajectory computation over trajectories.
 
         Parameters
         ----------
@@ -692,28 +721,33 @@ class TrajectoryGradientANOVA(GradientANOVA):
         GroupResults
             The trajectory results for `group_name` using the trajectory
             method
+
         """
         if len(trajectories) == 1:
             trajectory = np.array([np.linalg.norm(trajectories)])
-            calc = {'2-norm': trajectory[0]}
+            calc = {"2-norm": trajectory[0]}
         else:
             # Loop through all the rows in trajectories and create '2-norm'
             # by taking the norm of the 2nd row - 1st row, 3rd row - 2nd row...
-            trajectory = \
-                np.array([np.linalg.norm(trajectories.iloc[i+1].to_numpy() -
-                                         trajectories.iloc[i].to_numpy())
-                          for i in range(len(trajectories) - 1)])
-            calc = {'2-norm': np.linalg.norm(trajectory)}
+            trajectory = np.array(
+                [
+                    np.linalg.norm(
+                        trajectories.iloc[i + 1].to_numpy()
+                        - trajectories.iloc[i].to_numpy()
+                    )
+                    for i in range(len(trajectories) - 1)
+                ]
+            )
+            calc = {"2-norm": np.linalg.norm(trajectory)}
 
-        msg = ''.join(self._message_buffer) if self._message_buffer else None
+        msg = "".join(self._message_buffer) if self._message_buffer else None
         # Reset the message buffer
         self._message_buffer = []
-        return GroupResults(group_name, trajectory, np.mean(trajectory),
-                            calc, msg)
+        return GroupResults(group_name, trajectory, np.mean(trajectory), calc, msg)
 
 
 class FirstDifferenceGradientANOVA(GradientANOVA):
-    r"""Perform trajectory analysis using the first difference algorithm
+    r"""Perform trajectory analysis using the first difference algorithm.
 
     It calculates the norm for all the time-points and then calculates the
     first difference for each resulting point
@@ -721,12 +755,13 @@ class FirstDifferenceGradientANOVA(GradientANOVA):
     See Also
     --------
     GradientANOVA
+
     """
 
-    _alg_name = 'diff'
+    _alg_name = "diff"
 
     def _compute_trajectories_results(self, group_name, trajectories):
-        r"""Do the actual trajectory computation over trajectories
+        r"""Do the actual trajectory computation over trajectories.
 
         Parameters
         ----------
@@ -740,32 +775,35 @@ class FirstDifferenceGradientANOVA(GradientANOVA):
         GroupResults
             The trajectory results for `group_name` using the first difference
             method
+
         """
         if len(trajectories) == 1:
             trajectory = np.array([np.linalg.norm(trajectories)])
-            calc = {'mean': trajectory[0], 'std': 0}
+            calc = {"mean": trajectory[0], "std": 0}
         elif len(trajectories) == 2:
-            trajectory = np.array([np.linalg.norm(trajectories[1] -
-                                                  trajectories[0])])
-            calc = {'mean': trajectory[0], 'std': 0}
+            trajectory = np.array([np.linalg.norm(trajectories[1] - trajectories[0])])
+            calc = {"mean": trajectory[0], "std": 0}
         else:
-            vec_norm = \
-                np.array([np.linalg.norm(trajectories.iloc[i+1].to_numpy() -
-                                         trajectories.iloc[i].to_numpy())
-                          for i in range(len(trajectories) - 1)])
+            vec_norm = np.array(
+                [
+                    np.linalg.norm(
+                        trajectories.iloc[i + 1].to_numpy()
+                        - trajectories.iloc[i].to_numpy()
+                    )
+                    for i in range(len(trajectories) - 1)
+                ]
+            )
             trajectory = np.diff(vec_norm)
-            calc = {'mean': np.mean(trajectory), 'std': np.std(trajectory)}
+            calc = {"mean": np.mean(trajectory), "std": np.std(trajectory)}
 
-        msg = ''.join(self._message_buffer) if self._message_buffer else None
+        msg = "".join(self._message_buffer) if self._message_buffer else None
         # Reset the message buffer
         self._message_buffer = []
-        return GroupResults(group_name, trajectory, np.mean(trajectory),
-                            calc, msg)
+        return GroupResults(group_name, trajectory, np.mean(trajectory), calc, msg)
 
 
 class WindowDifferenceGradientANOVA(GradientANOVA):
-    r"""Perform trajectory analysis using the modified first difference
-    algorithm
+    r"""Perform trajectory analysis using the modified first difference algorithm.
 
     It calculates the norm for all the time-points and subtracts the mean of
     the next number of elements specified in `window_size` and the current
@@ -792,15 +830,16 @@ class WindowDifferenceGradientANOVA(GradientANOVA):
     See Also
     --------
     GradientANOVA
+
     """
 
-    _alg_name = 'wdiff'
+    _alg_name = "wdiff"
 
-    @experimental(as_of="0.4.0")
     def __init__(self, coords, prop_expl, metadata_map, window_size, **kwargs):
-        super(WindowDifferenceGradientANOVA, self).__init__(coords, prop_expl,
-                                                            metadata_map,
-                                                            **kwargs)
+        """Build all the attributes for the WindowDifferenceGradientANOVA object."""
+        super(WindowDifferenceGradientANOVA, self).__init__(
+            coords, prop_expl, metadata_map, **kwargs
+        )
 
         if not isinstance(window_size, Integral) or window_size < 1:
             raise ValueError("The window_size must be a positive integer")
@@ -808,7 +847,7 @@ class WindowDifferenceGradientANOVA(GradientANOVA):
         self._window_size = window_size
 
     def _compute_trajectories_results(self, group_name, trajectories):
-        r"""Do the actual trajectory computation over trajectories
+        r"""Do the actual trajectory computation over trajectories.
 
         If the first difference cannot be calculated of the provided window
         size, no difference is applied and a message is added to the results.
@@ -825,27 +864,34 @@ class WindowDifferenceGradientANOVA(GradientANOVA):
         GroupResults
             The trajectory results for `group_name` using the windowed
             difference method
+
         """
         if len(trajectories) == 1:
             trajectory = np.array([np.linalg.norm(trajectories)])
-            calc = {'mean': trajectory, 'std': 0}
+            calc = {"mean": trajectory, "std": 0}
         elif len(trajectories) == 2:
-            trajectory = np.array([np.linalg.norm(trajectories[1] -
-                                                  trajectories[0])])
-            calc = {'mean': trajectory, 'std': 0}
+            trajectory = np.array([np.linalg.norm(trajectories[1] - trajectories[0])])
+            calc = {"mean": trajectory, "std": 0}
         else:
-            vec_norm = \
-                np.array([np.linalg.norm(trajectories.iloc[i+1].to_numpy() -
-                                         trajectories.iloc[i].to_numpy())
-                          for i in range(len(trajectories) - 1)])
+            vec_norm = np.array(
+                [
+                    np.linalg.norm(
+                        trajectories.iloc[i + 1].to_numpy()
+                        - trajectories.iloc[i].to_numpy()
+                    )
+                    for i in range(len(trajectories) - 1)
+                ]
+            )
             # windowed first differences won't be able on every group,
             # specially given the variation of size that a trajectory tends
             # to have
             if len(vec_norm) <= self._window_size:
                 trajectory = vec_norm
-                self._message_buffer.append("Cannot calculate the first "
-                                            "difference with a window of size "
-                                            "(%d)." % self._window_size)
+                self._message_buffer.append(
+                    "Cannot calculate the first "
+                    "difference with a window of size "
+                    "(%d)." % self._window_size
+                )
             else:
                 # Replicate the last element as many times as required
                 for idx in range(0, self._window_size):
@@ -853,16 +899,15 @@ class WindowDifferenceGradientANOVA(GradientANOVA):
                 trajectory = []
                 for idx in range(0, len(vec_norm) - self._window_size):
                     # Meas has to be over axis 0 so it handles arrays of arrays
-                    element = np.mean(vec_norm[(idx + 1):
-                                               (idx + 1 + self._window_size)],
-                                      axis=0)
+                    element = np.mean(
+                        vec_norm[(idx + 1) : (idx + 1 + self._window_size)], axis=0
+                    )
                     trajectory.append(element - vec_norm[idx])
                 trajectory = np.array(trajectory)
 
-            calc = {'mean': np.mean(trajectory), 'std': np.std(trajectory)}
+            calc = {"mean": np.mean(trajectory), "std": np.std(trajectory)}
 
-        msg = ''.join(self._message_buffer) if self._message_buffer else None
+        msg = "".join(self._message_buffer) if self._message_buffer else None
         # Reset the message buffer
         self._message_buffer = []
-        return GroupResults(group_name, trajectory, np.mean(trajectory),
-                            calc, msg)
+        return GroupResults(group_name, trajectory, np.mean(trajectory), calc, msg)
