@@ -12,14 +12,12 @@ from scipy.linalg import svd
 
 from ._ordination_results import OrdinationResults
 from ._utils import svd_rank
-from skbio.util._decorator import experimental
 
 
-@experimental(as_of="0.4.0")
 def ca(X, scaling=1):
-    r"""Compute correspondence analysis, a multivariate statistical
-    technique for ordination.
+    r"""Compute correspondence analysis.
 
+    Correspondence analysis is a multivariate statistical technique for ordination.
     In general, rows in the data table will correspond to samples and
     columns to features, but the method is symmetric. In order to
     measure the correspondence between rows and columns, the
@@ -97,13 +95,11 @@ def ca(X, scaling=1):
        Amsterdam.
 
     """
-
     if scaling not in {1, 2}:
-        raise NotImplementedError(
-            "Scaling {0} not implemented.".format(scaling))
+        raise NotImplementedError("Scaling {0} not implemented.".format(scaling))
 
-    short_method_name = 'CA'
-    long_method_name = 'Correspondance Analysis'
+    short_method_name = "CA"
+    long_method_name = "Correspondance Analysis"
 
     # we deconstruct the dataframe to avoid duplicating the data and be able
     # to perform operations on the matrix
@@ -142,8 +138,8 @@ def ca(X, scaling=1):
 
     # Both scalings are a bit intertwined, so we'll compute both and
     # then choose
-    V = column_marginals[:, None]**-0.5 * U
-    V_hat = row_marginals[:, None]**-0.5 * U_hat
+    V = column_marginals[:, None] ** -0.5 * U
+    V_hat = row_marginals[:, None] ** -0.5 * U_hat
     F = V_hat * W
     # According to Formula 9.43, this should hold
     # assert np.allclose(F, (row_marginals**-1)[:, None] * Q.dot(V))
@@ -178,16 +174,24 @@ def ca(X, scaling=1):
     sample_scores = [F, V_hat][scaling - 1]
 
     # build the OrdinationResults object
-    sample_columns = ['%s%d' % (short_method_name, i+1)
-                      for i in range(sample_scores.shape[1])]
-    feature_columns = ['%s%d' % (short_method_name, i+1)
-                       for i in range(features_scores.shape[1])]
+    sample_columns = [
+        "%s%d" % (short_method_name, i + 1) for i in range(sample_scores.shape[1])
+    ]
+    feature_columns = [
+        "%s%d" % (short_method_name, i + 1) for i in range(features_scores.shape[1])
+    ]
 
-    eigvals = pd.Series(eigvals, ['%s%d' % (short_method_name, i+1) for i in
-                                  range(eigvals.shape[0])])
+    eigvals = pd.Series(
+        eigvals, ["%s%d" % (short_method_name, i + 1) for i in range(eigvals.shape[0])]
+    )
     samples = pd.DataFrame(sample_scores, row_ids, sample_columns)
     features = pd.DataFrame(features_scores, column_ids, feature_columns)
     proportion_explained = eigvals / eigvals.sum()
-    return OrdinationResults(short_method_name, long_method_name, eigvals,
-                             samples=samples, features=features,
-                             proportion_explained=proportion_explained)
+    return OrdinationResults(
+        short_method_name,
+        long_method_name,
+        eigvals,
+        samples=samples,
+        features=features,
+        proportion_explained=proportion_explained,
+    )
