@@ -1,5 +1,4 @@
-r"""
-Empirical Power Estimation (:mod:`skbio.stats.power`)
+r"""Empirical Power Estimation (:mod:`skbio.stats.power`)
 =====================================================
 
 .. currentmodule:: skbio.stats.power
@@ -64,8 +63,8 @@ step.
 >>> import numpy as np
 >>> np.random.seed(20)
 >>> ind = np.random.randint(0, 20, 15)
->>> ind
-array([ 3, 15,  9, 11,  7,  2,  0,  8, 19, 16,  6,  6, 16,  9,  5])
+>>> ind # doctest: +ELLIPSIS
+array([ 3, 15,  9, 11,  7,  2,  0,  8, 19, 16,  6,  6, 16,  9,  5]...
 >>> dep = (3 * ind + 5 + np.random.randn(15) * 5).round(3)
 >>> dep
 array([ 15.617,  47.533,  28.04 ,  33.788,  19.602,  12.229,   4.779,
@@ -130,7 +129,8 @@ Based on this power estimate, as we increase our confidence that we have not
 committed a type I error and identified a false positive, the number of samples
 we need to be confident that we have not committed a type II error increases.
 
-"""
+
+"""  # noqa: D205, D415
 
 # ----------------------------------------------------------------------------
 # Copyright (c) 2013--, scikit-bio development team.
@@ -146,14 +146,20 @@ import copy
 import numpy as np
 import scipy.stats
 
-from skbio.util._decorator import experimental
 
-
-@experimental(as_of="0.4.0")
-def subsample_power(test, samples, draw_mode='ind', alpha_pwr=0.05, ratio=None,
-                    max_counts=50, counts_interval=10, min_counts=None,
-                    num_iter=500, num_runs=10):
-    r"""Subsamples data to iteratively calculate power
+def subsample_power(
+    test,
+    samples,
+    draw_mode="ind",
+    alpha_pwr=0.05,
+    ratio=None,
+    max_counts=50,
+    counts_interval=10,
+    min_counts=None,
+    num_iter=500,
+    num_runs=10,
+):
+    r"""Subsample data to iteratively calculate power.
 
     Parameters
     ----------
@@ -346,16 +352,16 @@ def subsample_power(test, samples, draw_mode='ind', alpha_pwr=0.05, ratio=None,
     power.
 
     """
-
     # Checks the inputs
-    ratio, num_p, sample_counts = \
-        _check_subsample_power_inputs(test=test,
-                                      samples=samples,
-                                      draw_mode=draw_mode,
-                                      ratio=ratio,
-                                      min_counts=min_counts,
-                                      max_counts=max_counts,
-                                      counts_interval=counts_interval)
+    ratio, num_p, sample_counts = _check_subsample_power_inputs(
+        test=test,
+        samples=samples,
+        draw_mode=draw_mode,
+        ratio=ratio,
+        min_counts=min_counts,
+        max_counts=max_counts,
+        counts_interval=counts_interval,
+    )
 
     # Prealocates the power array
     power = np.zeros((num_runs, len(sample_counts), num_p))
@@ -364,12 +370,14 @@ def subsample_power(test, samples, draw_mode='ind', alpha_pwr=0.05, ratio=None,
     for id2, c in enumerate(sample_counts):
         count = np.round(c * ratio, 0).astype(int)
         for id1 in range(num_runs):
-            ps = _compare_distributions(test=test,
-                                        samples=samples,
-                                        num_p=num_p,
-                                        counts=count,
-                                        num_iter=num_iter,
-                                        mode=draw_mode)
+            ps = _compare_distributions(
+                test=test,
+                samples=samples,
+                num_p=num_p,
+                counts=count,
+                num_iter=num_iter,
+                mode=draw_mode,
+            )
             power[id1, id2, :] = _calculate_power(ps, alpha_pwr)
 
     power = power.squeeze()
@@ -377,12 +385,21 @@ def subsample_power(test, samples, draw_mode='ind', alpha_pwr=0.05, ratio=None,
     return power, sample_counts
 
 
-@experimental(as_of="0.4.0")
-def subsample_paired_power(test, meta, cat, control_cats, order=None,
-                           strict_match=True, alpha_pwr=0.05,
-                           max_counts=50, counts_interval=10, min_counts=None,
-                           num_iter=500, num_runs=10):
-    r"""Estimates power iteratively using samples with matching metadata
+def subsample_paired_power(
+    test,
+    meta,
+    cat,
+    control_cats,
+    order=None,
+    strict_match=True,
+    alpha_pwr=0.05,
+    max_counts=50,
+    counts_interval=10,
+    min_counts=None,
+    num_iter=500,
+    num_runs=10,
+):
+    r"""Estimate power iteratively using samples with matching metadata.
 
     Parameters
     ----------
@@ -525,26 +542,31 @@ def subsample_paired_power(test, meta, cat, control_cats, order=None,
     samples per group.
 
     """
-
     # Handles the order argument
     if order is None:
         order = sorted(meta.groupby(cat).groups.keys())
     order = np.array(order)
 
     # Checks for the number of sampling pairs available
-    meta_pairs, index = _identify_sample_groups(meta, cat, control_cats, order,
-                                                strict_match)
-    min_obs = min([_get_min_size(meta, cat, control_cats, order, strict_match),
-                  np.floor(len(index)*0.9)])
+    meta_pairs, index = _identify_sample_groups(
+        meta, cat, control_cats, order, strict_match
+    )
+    min_obs = min(
+        [
+            _get_min_size(meta, cat, control_cats, order, strict_match),
+            np.floor(len(index) * 0.9),
+        ]
+    )
     sub_ids = _draw_paired_samples(meta_pairs, index, min_obs)
 
-    ratio, num_p, sample_counts = \
-        _check_subsample_power_inputs(test=test,
-                                      samples=sub_ids,
-                                      draw_mode='matched',
-                                      min_counts=min_counts,
-                                      max_counts=max_counts,
-                                      counts_interval=counts_interval)
+    ratio, num_p, sample_counts = _check_subsample_power_inputs(
+        test=test,
+        samples=sub_ids,
+        draw_mode="matched",
+        min_counts=min_counts,
+        max_counts=max_counts,
+        counts_interval=counts_interval,
+    )
 
     # Prealocates the power array
     power = np.zeros((num_runs, len(sample_counts), num_p))
@@ -563,9 +585,8 @@ def subsample_paired_power(test, meta, cat, control_cats, order=None,
     return power, sample_counts
 
 
-@experimental(as_of="0.4.0")
 def confidence_bound(vec, alpha=0.05, df=None, axis=None):
-    r"""Calculates a confidence bound assuming a normal distribution
+    r"""Calculate a confidence bound assuming a normal distribution.
 
     Parameters
     ----------
@@ -588,7 +609,6 @@ def confidence_bound(vec, alpha=0.05, df=None, axis=None):
         [mean - bound, mean + bound].
 
     """
-
     # Determines the number of non-nan counts
     vec = np.asarray(vec)
     vec_shape = vec.shape
@@ -597,8 +617,9 @@ def confidence_bound(vec, alpha=0.05, df=None, axis=None):
     elif axis is None:
         num_counts = vec_shape[0] * vec_shape[1] - np.isnan(vec).sum()
     else:
-        num_counts = vec_shape[axis] - np.isnan(vec).sum() / \
-            (vec_shape[0] * vec_shape[1])
+        num_counts = vec_shape[axis] - np.isnan(vec).sum() / (
+            vec_shape[0] * vec_shape[1]
+        )
 
     # Gets the df if not supplied
     if df is None:
@@ -607,15 +628,17 @@ def confidence_bound(vec, alpha=0.05, df=None, axis=None):
     # Calculates the bound
     # In the conversion from scipy.stats.nanstd -> np.nanstd `ddof=1` had to be
     # added to match the scipy default of `bias=False`.
-    bound = np.nanstd(vec, axis=axis, ddof=1) / np.sqrt(num_counts - 1) * \
-        scipy.stats.t.ppf(1 - alpha / 2, df)
+    bound = (
+        np.nanstd(vec, axis=axis, ddof=1)
+        / np.sqrt(num_counts - 1)
+        * scipy.stats.t.ppf(1 - alpha / 2, df)
+    )
 
     return bound
 
 
-@experimental(as_of="0.4.0")
 def paired_subsamples(meta, cat, control_cats, order=None, strict_match=True):
-    r"""Draws a list of samples varied by `cat` and matched for `control_cats`
+    r"""Draw a list of samples varied by `cat` and matched for `control_cats`.
 
     This function is designed to provide controlled samples, based on a
     metadata category. For example, one could control for age, sex, education
@@ -685,7 +708,6 @@ def paired_subsamples(meta, cat, control_cats, order=None, strict_match=True):
     `strict_match` was true, and there is missing AGE data for this sample.
 
     """
-
     # Handles the order argument
     if order is None:
         order = sorted(meta.groupby(cat).groups.keys())
@@ -695,23 +717,22 @@ def paired_subsamples(meta, cat, control_cats, order=None, strict_match=True):
     min_obs = _get_min_size(meta, cat, control_cats, order, strict_match)
 
     # Identifies all possible subsamples
-    meta_pairs, index = _identify_sample_groups(meta=meta,
-                                                cat=cat,
-                                                control_cats=control_cats,
-                                                order=order,
-                                                strict_match=strict_match)
+    meta_pairs, index = _identify_sample_groups(
+        meta=meta,
+        cat=cat,
+        control_cats=control_cats,
+        order=order,
+        strict_match=strict_match,
+    )
 
     # Draws paired ids
-    ids = _draw_paired_samples(meta_pairs=meta_pairs,
-                               index=index,
-                               num_samps=min_obs)
+    ids = _draw_paired_samples(meta_pairs=meta_pairs, index=index, num_samps=min_obs)
 
     return ids
 
 
 def _get_min_size(meta, cat, control_cats, order, strict_match):
-    """Determines the smallest group represented"""
-
+    """Determine the smallest group represented."""
     if strict_match:
         all_cats = copy.deepcopy(control_cats)
         all_cats.append(cat)
@@ -721,8 +742,7 @@ def _get_min_size(meta, cat, control_cats, order, strict_match):
 
 
 def _check_nans(x, switch=False):
-    r"""Returns False if x is a nan and True is x is a string or number
-    """
+    r"""Return False if x is a nan and True is x is a string or number."""
     if isinstance(x, str):
         return True
     elif isinstance(x, (float, int)):
@@ -732,11 +752,11 @@ def _check_nans(x, switch=False):
     elif switch and isinstance(x, (list, tuple)):
         return True
     else:
-        raise TypeError('input must be a string, float or a nan')
+        raise TypeError("input must be a string, float or a nan")
 
 
 def _calculate_power(p_values, alpha=0.05):
-    r"""Calculates statistical power empirically
+    r"""Calculate statistical power empirically.
 
     Parameters
     ----------
@@ -753,17 +773,15 @@ def _calculate_power(p_values, alpha=0.05):
         critical value.
 
     """
-
     p_values = np.atleast_2d(p_values)
 
-    w = (p_values < alpha).sum(axis=1)/p_values.shape[1]
+    w = (p_values < alpha).sum(axis=1) / p_values.shape[1]
 
     return w
 
 
-def _compare_distributions(test, samples, num_p, counts=5, mode="ind",
-                           num_iter=100):
-    r"""Compares two distribution arrays iteratively
+def _compare_distributions(test, samples, num_p, counts=5, mode="ind", num_iter=100):
+    r"""Compare two distribution arrays iteratively.
 
     Parameters
     ----------
@@ -810,7 +828,6 @@ def _compare_distributions(test, samples, num_p, counts=5, mode="ind",
         If counts is a 1-D array and counts and samples are different lengths.
 
     """
-
     # Prealocates the pvalue matrix
     p_values = np.zeros((num_p, num_iter))
 
@@ -823,12 +840,13 @@ def _compare_distributions(test, samples, num_p, counts=5, mode="ind",
 
     for idx in range(num_iter):
         if mode == "matched":
-            pos = np.random.choice(np.arange(0, samp_lens[0]), counts[0],
-                                   replace=False)
+            pos = np.random.choice(np.arange(0, samp_lens[0]), counts[0], replace=False)
             subs = [sample[pos] for sample in samples]
         else:
-            subs = [np.random.choice(np.array(pop), counts[i], replace=False)
-                    for i, pop in enumerate(samples)]
+            subs = [
+                np.random.choice(np.array(pop), counts[i], replace=False)
+                for i, pop in enumerate(samples)
+            ]
 
         p_values[:, idx] = test(subs)
 
@@ -838,10 +856,16 @@ def _compare_distributions(test, samples, num_p, counts=5, mode="ind",
     return p_values
 
 
-def _check_subsample_power_inputs(test, samples, draw_mode='ind', ratio=None,
-                                  max_counts=50, counts_interval=10,
-                                  min_counts=None):
-    r"""Makes sure that everything is sane before power calculations
+def _check_subsample_power_inputs(
+    test,
+    samples,
+    draw_mode="ind",
+    ratio=None,
+    max_counts=50,
+    counts_interval=10,
+    min_counts=None,
+):
+    r"""Make sure that everything is sane before power calculations.
 
     Parameters
     ----------
@@ -903,8 +927,7 @@ def _check_subsample_power_inputs(test, samples, draw_mode='ind', ratio=None,
         `test` does not return a float or a 1-dimensional numpy array.
 
     """
-
-    if draw_mode not in {'ind', 'matched'}:
+    if draw_mode not in {"ind", "matched"}:
         raise ValueError('mode must be "matched" or "ind".')
 
     # Determines the minimum number of ids in a category
@@ -917,8 +940,10 @@ def _check_subsample_power_inputs(test, samples, draw_mode='ind', ratio=None,
     if draw_mode == "matched":
         for id_ in samples:
             if not len(id_) == num_ids:
-                raise ValueError('Each vector in samples must be the same '
-                                 'length in "matched" draw_mode.')
+                raise ValueError(
+                    "Each vector in samples must be the same "
+                    'length in "matched" draw_mode.'
+                )
 
     # Checks the number of counts is appropriate
     if min_counts is None:
@@ -927,15 +952,14 @@ def _check_subsample_power_inputs(test, samples, draw_mode='ind', ratio=None,
         raise ValueError("No subsamples of the specified size can be drawn.")
 
     # Checks the ratio argument is sane
-    if ratio is None or draw_mode == 'matched':
+    if ratio is None or draw_mode == "matched":
         ratio = np.ones((num_groups))
     else:
         ratio = np.asarray(ratio)
     if not ratio.shape == (num_groups,):
-        raise ValueError('There must be a ratio for each group.')
+        raise ValueError("There must be a ratio for each group.")
 
-    ratio_counts = np.array([id_counts[i] / ratio[i]
-                             for i in range(num_groups)])
+    ratio_counts = np.array([id_counts[i] / ratio[i] for i in range(num_groups)])
     largest = ratio_counts.min()
 
     # Determines the number of p values returned by the test
@@ -945,18 +969,16 @@ def _check_subsample_power_inputs(test, samples, draw_mode='ind', ratio=None,
     elif isinstance(p_return, np.ndarray) and len(p_return.shape) == 1:
         num_p = p_return.shape[0]
     else:
-        raise TypeError('test must return a float or one-dimensional array.')
+        raise TypeError("test must return a float or one-dimensional array.")
 
     # Calculates the same counts
-    sample_counts = np.arange(min_counts,
-                              min(max_counts, largest),
-                              counts_interval)
+    sample_counts = np.arange(min_counts, min(max_counts, largest), counts_interval)
 
     return ratio, num_p, sample_counts
 
 
 def _identify_sample_groups(meta, cat, control_cats, order, strict_match):
-    """Aggregates samples matches for `control_cats` that vary by `cat`
+    """Aggregate samples matches for `control_cats` that vary by `cat`.
 
     Parameters
     ----------
@@ -997,7 +1019,6 @@ def _identify_sample_groups(meta, cat, control_cats, order, strict_match):
         position of the reference group sample in the list of samples.
 
     """
-
     # Sets up variables to be filled
     meta_pairs = {}
     index = []
@@ -1017,15 +1038,14 @@ def _identify_sample_groups(meta, cat, control_cats, order, strict_match):
         m_ids = meta.loc[ids].groupby(cat).groups
         # Checks if samples from the cat groups are represented in those
         # Samples
-        id_vecs = [sorted(m_ids[o]) for o in order if o in
-                   m_ids]
+        id_vecs = [sorted(m_ids[o]) for o in order if o in m_ids]
         # If all groups are represented, the index and results are retained
         if len(id_vecs) == len(order):
             min_vec = np.array([len(v) for v in id_vecs])
             loc_vec = np.arange(0, min_vec.min())
             meta_pairs[i1] = id_vecs
             index.append(np.zeros(loc_vec.shape) + i1)
-            i1 = i1 + 1
+            i1 += 1
         # If the groups are not represented, an empty array gets passed
         else:
             index.append(np.array([]))
@@ -1035,13 +1055,13 @@ def _identify_sample_groups(meta, cat, control_cats, order, strict_match):
 
     # If index is empty, sets up meta_paris with a no key.
     if not meta_pairs:
-        meta_pairs['no'] = order
+        meta_pairs["no"] = order
 
     return meta_pairs, index
 
 
 def _draw_paired_samples(meta_pairs, index, num_samps):
-    """Draws a random set of ids from a matched list
+    """Draw a random set of ids from a matched list.
 
     Parameters
     ----------
@@ -1055,20 +1075,21 @@ def _draw_paired_samples(meta_pairs, index, num_samps):
         The first array is an index array. The second gives an integer
         corresponding to the `control_cat`-group, and the third lists the
         position of the reference group sample in the list of samples.
+    num_samps : int
+        The number of samples.
 
     Returns
     -------
     ids : list
         A set of randomly selected ids groups from each group.
-    """
 
+    """
     # Handles an empty paired vector
-    if 'no' in meta_pairs:
-        return [np.array([]) for o in meta_pairs['no']]
+    if "no" in meta_pairs:
+        return [np.array([]) for o in meta_pairs["no"]]
 
     # Identifies the absolute positions of the control group being drawn
-    set_pos = np.random.choice(index, int(num_samps),
-                               replace=False).astype(int)
+    set_pos = np.random.choice(index, int(num_samps), replace=False).astype(int)
 
     subs = []
 
@@ -1087,8 +1108,7 @@ def _draw_paired_samples(meta_pairs, index, num_samps):
     # now set_list is ordered and we can iterate over it to get counter obj
     for set_ in set_list:
         num_ = counter[set_]
-        r2 = [np.random.choice(col, num_, replace=False) for col in
-              meta_pairs[set_]]
+        r2 = [np.random.choice(col, num_, replace=False) for col in meta_pairs[set_]]
         subs.append(r2)
 
     ids = [np.hstack(ids) for ids in zip(*subs)]
@@ -1096,9 +1116,10 @@ def _draw_paired_samples(meta_pairs, index, num_samps):
     return ids
 
 
-def _calculate_power_curve(test, samples, sample_counts, ratio=None,
-                           mode='ind', num_iter=1000, alpha=0.05):
-    r"""Generates an empirical power curve for the samples.
+def _calculate_power_curve(
+    test, samples, sample_counts, ratio=None, mode="ind", num_iter=1000, alpha=0.05
+):
+    r"""Generate an empirical power curve for the samples.
 
     Parameters
     ----------
@@ -1125,15 +1146,19 @@ def _calculate_power_curve(test, samples, sample_counts, ratio=None,
     num_iter : int
         The default is 1000. The number of p-values to generate for each point
         on the curve.
+    alpha : float, optional
+        The significance level for the statistical test. Defaults to 0.05.
 
     Returns
     -------
     p_values : array
         The p-values associated with the input sample counts.
+
     Raises
     ------
     ValueError
         If ratio is an array and ratio is not the same length as samples
+
     """
     # Casts array-likes to arrays
     sample_counts = np.asarray(sample_counts)
@@ -1153,20 +1178,23 @@ def _calculate_power_curve(test, samples, sample_counts, ratio=None,
         ratio = np.ones((num_groups))
     ratio = np.asarray(ratio)
     if not ratio.shape == (num_groups,):
-        raise ValueError('There must be a ratio for each group.')
+        raise ValueError("There must be a ratio for each group.")
 
     # Loops through the sample sizes
     for id2, s in enumerate(sample_counts):
         count = np.round(s * ratio, 0).astype(int)
         for id1, a in enumerate(alpha):
-            ps = _compare_distributions(test=test,
-                                        samples=samples,
-                                        counts=count,
-                                        num_p=1,
-                                        num_iter=num_iter,
-                                        mode=mode)
+            ps = _compare_distributions(
+                test=test,
+                samples=samples,
+                counts=count,
+                num_p=1,
+                num_iter=num_iter,
+                mode=mode,
+            )
             if vec:
-                pwr[id2] = _calculate_power(ps, a)
+                pwr[id2] = (_calculate_power(ps, a)).item()
+
             else:
                 pwr[id1, id2] = _calculate_power(ps, a)
 
