@@ -8,25 +8,30 @@
 
 
 class TreeError(Exception):
-    """General tree error"""
+    """General tree error."""
+
     pass
 
 
 class NoLengthError(TreeError):
-    """Missing length when expected"""
+    """Missing length when expected."""
+
     pass
 
 
 class DuplicateNodeError(TreeError):
-    """Duplicate nodes with identical names"""
+    """Duplicate nodes with identical names."""
+
     pass
 
 
 class MissingNodeError(TreeError):
-    """Expecting a node"""
+    """Expecting a node."""
+
     pass
 
 
 class NoParentError(MissingNodeError):
-    """Missing a parent"""
+    """Missing a parent."""
+
     pass
